@@ -6,11 +6,18 @@
 
 #include  <stdio.h>		/* NULL */
 #include  <string.h>		/* strlen */
-#include  <limits.h>		/* MAX_PATH */
+
 #include  "kik_mem.h"		/* alloca() */
 
+#define  _WIN32_WINNT 0x0502	/* for SetDllDirectory */
 #include  <windows.h>
-#include  <winbase.h>
+#include  <winbase.h>		/* SetDllDirectory */
+
+
+/* --- static functions --- */
+
+static int  initialized ;
+
 
 /* --- global functions --- */
 
@@ -23,7 +30,16 @@ kik_dl_open(
 	HMODULE  module ;
 	char *  path ;
 #if defined(__CYGWIN__) || defined(__MSYS__)
-	char  winpath[MAX_PATH];
+	/* MAX_PATH which is 260 (3+255+1+1) is defined in win32 alone. */
+	char  winpath[MAX_PATH] ;
+#endif
+
+#ifdef  SetDllDirectory		/* Defined in winbase.h as SetDllDirectoryA or SetDllDirectoryW */
+	if( ! initialized)
+	{
+		SetDllDirectory( "") ;	/* Don't load library at CWD. */
+		initialized = 1 ;
+	}
 #endif
 
 	if( ( path = alloca( strlen( dirpath) + strlen( name) + 8)) == NULL)
