@@ -17,10 +17,247 @@
 
 
 #if  0
-#define   __DEBUG
+#define  __DEBUG
 #endif
 
 
+#ifndef  HAVE_ALLOCA
+
+#define  ALLOCA_PAGE_UNIT_SIZE  4096
+#define  MAX_STACK_FRAMES  10
+
+
+typedef struct  alloca_page
+{
+	void *  ptr ;
+	size_t  size ;
+	size_t  used_size ;
+
+	struct alloca_page *  prev_page ;
+
+} alloca_page_t ;
+
+
+/* --- static variables --- */
+
+static size_t  total_allocated_size = 0 ;
+static alloca_page_t *  alloca_page ;
+static int  stack_frame_bases[MAX_STACK_FRAMES] ;
+static int  current_stack_frame = 0 ;
+
+
+/* --- global functions --- */
+
+void *
+kik_alloca(
+	size_t  size
+	)
+{
+	void *  ptr ;
+
+	/* arranging bytes boundary */
+	size = ((size + sizeof(char *) - 1) / sizeof(char *)) * sizeof(char *) ;
+	
+	if( alloca_page == NULL || alloca_page->used_size + size > alloca_page->size)
+	{
+		alloca_page_t *  new_page ;
+		
+		if( ( new_page = malloc( sizeof( alloca_page_t))) == NULL)
+		{
+			return  NULL ;
+		}
+		
+		new_page->size = ((size / ALLOCA_PAGE_UNIT_SIZE) + 1) * ALLOCA_PAGE_UNIT_SIZE ;
+		new_page->used_size = 0 ;
+		
+		if( ( new_page->ptr = malloc( new_page->size)) == NULL)
+		{
+			free( new_page) ;
+			
+			return  NULL ;
+		}
+
+	#ifdef  DEBUG
+		memset( new_page->ptr , 0xff , new_page->size) ;
+	#endif
+
+	#ifdef  __DEBUG
+		fprintf( stderr , "new page(size %d) created.\n" , new_page->size) ;
+	#endif
+	
+		new_page->prev_page = alloca_page ;
+		alloca_page = new_page ;
+	}
+
+	/* operations of void * cannot be done in some operating systems */
+	ptr = (char *)alloca_page->ptr + alloca_page->used_size ;
+	
+	alloca_page->used_size += size ;
+	total_allocated_size += size ;
+
+#ifdef  __DEBUG
+	fprintf( stderr , "memory %p(size %d) was successfully allocated.\n" , ptr , size) ;
+#endif
+	
+	return  ptr ;
+}
+
+int
+kik_alloca_begin_stack_frame(void)
+{
+	if( alloca_page == NULL)
+	{
+		/* no page is found */
+
+		return  0 ;
+	}
+
+	current_stack_frame ++ ;
+	
+	if( current_stack_frame >= MAX_STACK_FRAMES)
+	{
+	#ifdef  __DEBUG
+		fprintf( stderr , "end of stack frame.\n") ;
+	#endif
+	
+		return  1 ;
+	}
+#ifdef  DEBUG
+	else if( current_stack_frame < 0)
+	{
+		fprintf( stderr , "current stack frame must not be less than 0.\n") ;
+	
+		return  1 ;
+	}
+#endif
+
+	stack_frame_bases[current_stack_frame] = total_allocated_size ;
+
+#ifdef  __DEBUG
+	fprintf( stderr ,  "stack frame (base %d (%d) size 0) created.\n" ,
+		stack_frame_bases[current_stack_frame] , current_stack_frame) ;
+#endif
+
+	return  1 ;
+}
+
+int
+kik_alloca_end_stack_frame(void)
+{
+	if( alloca_page == NULL)
+	{
+		/* no page is found */
+
+		return  0 ;
+	}
+
+	if( current_stack_frame == 0)
+	{
+	#ifdef  __DEBUG
+		fprintf( stderr , "beg of stack frame.\n") ;
+	#endif
+	
+		return  1 ;
+	}
+#ifdef  DEBUG
+	else if( current_stack_frame < 0)
+	{
+		fprintf( stderr , "current stack frame must not be less than 0.\n") ;
+	
+		return  1 ;
+	}
+#endif
+	else if( current_stack_frame < MAX_STACK_FRAMES)
+	{
+		size_t  shrink_size ;
+		alloca_page_t *  page ;
+		
+	#ifdef  __DEBUG
+		fprintf( stderr , "stack frame (base %d (%d) size %d) deleted\n" ,
+			stack_frame_bases[current_stack_frame] ,
+			current_stack_frame ,
+			total_allocated_size - stack_frame_bases[current_stack_frame]) ;
+	#endif
+	
+		shrink_size = total_allocated_size - stack_frame_bases[current_stack_frame] ;
+
+		page = alloca_page ;
+
+		while( shrink_size > page->used_size)
+		{
+			alloca_page_t *  _page ;
+
+			if( ( _page = page->prev_page) == NULL)
+			{
+			#ifdef  DEBUG
+				fprintf( stderr , "strange page link list...\n") ;
+			#endif
+
+				/* so as not to seg fault ... */
+				shrink_size = page->used_size ;
+
+				break ;
+			}
+			
+			shrink_size -= page->used_size ;
+			
+		#ifdef  __DEBUG
+			fprintf( stderr , "page(size %d) deleted.\n" , page->size) ;
+		#endif
+			
+			free( page->ptr) ;
+			free( page) ;
+
+			page = _page ;
+		}
+		
+		alloca_page = page ;
+
+		alloca_page->used_size -= shrink_size ;
+		
+		total_allocated_size = stack_frame_bases[current_stack_frame] ;
+	}
+
+	current_stack_frame -- ;
+	
+	return  1 ;
+}
+
+int
+kik_alloca_garbage_collect(void)
+{
+	alloca_page_t *  page ;
+	
+#ifdef  __DEBUG
+	fprintf( stderr , "allocated memory(size %d) for alloca() is discarded.\n" ,
+		total_allocated_size) ;
+#endif
+
+	page = alloca_page ;
+
+	while( page)
+	{
+		alloca_page_t *  _page ;
+		
+		_page = page->prev_page ;
+
+		free( page->ptr) ;
+		free( page) ;
+
+		page = _page ;
+	}
+	
+	alloca_page = NULL ;
+	
+	total_allocated_size = 0 ;
+	current_stack_frame = 0 ;
+
+	return  1 ;
+}
+
+#endif	/* HAVE_ALLOCA */
+
+
 #undef  malloc
 #undef  calloc
 #undef  realloc
@@ -325,242 +562,3 @@ kik_mem_free_all(void)
 		return  1 ;
 	}
 }
-
-
-#ifndef  HAVE_ALLOCA
-
-#if  0
-#define  __DEBUG
-#endif
-
-#define  ALLOCA_PAGE_UNIT_SIZE  4096
-#define  MAX_STACK_FRAMES  10
-
-typedef struct  alloca_page
-{
-	void *  ptr ;
-	size_t  size ;
-	size_t  used_size ;
-
-	struct alloca_page *  prev_page ;
-
-} alloca_page_t ;
-
-
-/* --- static variables --- */
-
-static size_t  total_allocated_size = 0 ;
-static alloca_page_t *  alloca_page ;
-static int  stack_frame_bases[MAX_STACK_FRAMES] ;
-static int  current_stack_frame = 0 ;
-
-
-/* --- global functions --- */
-
-void *
-kik_alloca(
-	size_t  size
-	)
-{
-	void *  ptr ;
-
-	/* arranging bytes boundary */
-	size = ((size + sizeof(char *) - 1) / sizeof(char *)) * sizeof(char *) ;
-	
-	if( alloca_page == NULL || alloca_page->used_size + size > alloca_page->size)
-	{
-		alloca_page_t *  new_page ;
-		
-		if( ( new_page = malloc( sizeof( alloca_page_t))) == NULL)
-		{
-			return  NULL ;
-		}
-		
-		new_page->size = ((size / ALLOCA_PAGE_UNIT_SIZE) + 1) * ALLOCA_PAGE_UNIT_SIZE ;
-		new_page->used_size = 0 ;
-		
-		if( ( new_page->ptr = malloc( new_page->size)) == NULL)
-		{
-			free( new_page) ;
-			
-			return  NULL ;
-		}
-
-	#ifdef  DEBUG
-		memset( new_page->ptr , 0xff , new_page->size) ;
-	#endif
-
-	#ifdef  __DEBUG
-		fprintf( stderr , "new page(size %d) created.\n" , new_page->size) ;
-	#endif
-	
-		new_page->prev_page = alloca_page ;
-		alloca_page = new_page ;
-	}
-
-	/* operations of void * cannot be done in some operating systems */
-	ptr = (char *)alloca_page->ptr + alloca_page->used_size ;
-	
-	alloca_page->used_size += size ;
-	total_allocated_size += size ;
-
-#ifdef  __DEBUG
-	fprintf( stderr , "memory %p(size %d) was successfully allocated.\n" , ptr , size) ;
-#endif
-	
-	return  ptr ;
-}
-
-int
-kik_alloca_begin_stack_frame(void)
-{
-	if( alloca_page == NULL)
-	{
-		/* no page is found */
-
-		return  0 ;
-	}
-
-	current_stack_frame ++ ;
-	
-	if( current_stack_frame >= MAX_STACK_FRAMES)
-	{
-	#ifdef  __DEBUG
-		fprintf( stderr , "end of stack frame.\n") ;
-	#endif
-	
-		return  1 ;
-	}
-#ifdef  DEBUG
-	else if( current_stack_frame < 0)
-	{
-		fprintf( stderr , "current stack frame must not be less than 0.\n") ;
-	
-		return  1 ;
-	}
-#endif
-
-	stack_frame_bases[current_stack_frame] = total_allocated_size ;
-
-#ifdef  __DEBUG
-	fprintf( stderr ,  "stack frame (base %d (%d) size 0) created.\n" ,
-		stack_frame_bases[current_stack_frame] , current_stack_frame) ;
-#endif
-
-	return  1 ;
-}
-
-int
-kik_alloca_end_stack_frame(void)
-{
-	if( alloca_page == NULL)
-	{
-		/* no page is found */
-
-		return  0 ;
-	}
-
-	if( current_stack_frame == 0)
-	{
-	#ifdef  __DEBUG
-		fprintf( stderr , "beg of stack frame.\n") ;
-	#endif
-	
-		return  1 ;
-	}
-#ifdef  DEBUG
-	else if( current_stack_frame < 0)
-	{
-		fprintf( stderr , "current stack frame must not be less than 0.\n") ;
-	
-		return  1 ;
-	}
-#endif
-	else if( current_stack_frame < MAX_STACK_FRAMES)
-	{
-		size_t  shrink_size ;
-		alloca_page_t *  page ;
-		
-	#ifdef  __DEBUG
-		fprintf( stderr , "stack frame (base %d (%d) size %d) deleted\n" ,
-			stack_frame_bases[current_stack_frame] ,
-			current_stack_frame ,
-			total_allocated_size - stack_frame_bases[current_stack_frame]) ;
-	#endif
-	
-		shrink_size = total_allocated_size - stack_frame_bases[current_stack_frame] ;
-
-		page = alloca_page ;
-
-		while( shrink_size > page->used_size)
-		{
-			alloca_page_t *  _page ;
-
-			if( ( _page = page->prev_page) == NULL)
-			{
-			#ifdef  DEBUG
-				fprintf( stderr , "strange page link list...\n") ;
-			#endif
-
-				/* so as not to seg fault ... */
-				shrink_size = page->used_size ;
-
-				break ;
-			}
-			
-			shrink_size -= page->used_size ;
-			
-		#ifdef  __DEBUG
-			fprintf( stderr , "page(size %d) deleted.\n" , page->size) ;
-		#endif
-			
-			free( page->ptr) ;
-			free( page) ;
-
-			page = _page ;
-		}
-		
-		alloca_page = page ;
-
-		alloca_page->used_size -= shrink_size ;
-		
-		total_allocated_size = stack_frame_bases[current_stack_frame] ;
-	}
-
-	current_stack_frame -- ;
-	
-	return  1 ;
-}
-
-int
-kik_alloca_garbage_collect(void)
-{
-	alloca_page_t *  page ;
-	
-#ifdef  __DEBUG
-	fprintf( stderr , "allocated memory(size %d) for alloca() is discarded.\n" ,
-		total_allocated_size) ;
-#endif
-
-	page = alloca_page ;
-
-	while( page)
-	{
-		alloca_page_t *  _page ;
-		
-		_page = page->prev_page ;
-		
-		free( page->ptr) ;
-		free( page) ;
-
-		page = _page ;
-	}
-	
-	alloca_page = NULL ;
-	
-	total_allocated_size = 0 ;
-
-	return  1 ;
-}
-
-#endif	/* HAVE_ALLOCA */
