@@ -7,7 +7,7 @@
 
 
 #include  "kik_types.h"		/* size_t */
-#include  "kik_config.h"
+#include  "kik_def.h"
 #include  "kik_mem.h"		/* alloca */
 
 
@@ -66,5 +66,7 @@ int  kik_str_to_int( int *  i , const char *  s) ;
 
 u_int  kik_count_char_in_str( const char *  str , char  ch) ;
 
+int  kik_compare_str( const char *  str1 , const char *  str2) ;
+
 
 #endif
