@@ -1,11 +1,10 @@
 /*
- *	$Id: mkf_char.c,v 1.4 2005/02/04 17:51:14 seiichi Exp $
+ *	$Id$
  */
 
 #include  "mkf_char.h"
 
 #include  <stdio.h>		/* NULL */
-#include  <kiklib/kik_debug.h>
 
 
 /* --- global functions --- */
@@ -30,10 +29,6 @@ mkf_char_to_int(
 	}
 	else
 	{
-	#ifdef  DEBUG
-		kik_warn_printf( KIK_DEBUG_TAG " mkf_char_t couldn't be converted to int.\n") ;
-	#endif
-	
 		return  0 ;
 	}
 }
@@ -71,7 +66,7 @@ mkf_int_to_bytes(
 
 u_int32_t
 mkf_bytes_to_int(
-	u_char *  bytes ,
+	const u_char *  bytes ,
 	size_t  len
 	)
 {
