@@ -1,5 +1,5 @@
 /*
- *	$Id: mkf_utf16_parser.c,v 1.4 2004/12/09 09:43:42 h_minami Exp $
+ *	$Id$
  */
 
 #include  "mkf_utf16_parser.h"
@@ -157,7 +157,7 @@ utf16_parser_next_char(
 					(ch2[0] - 0xdc) * 0x100 + ch2[1] ) + 0x10000 ;
 
 		#ifdef  DEBUG
-			if( ucs4 < 0x10000 || 0x1fffff < ucs4)
+			if( ucs4 < 0x10000 || 0x10ffff < ucs4)
 			{
 				kik_warn_printf( KIK_DEBUG_TAG " illegal UTF-16 surrogate-pair format.\n") ;
 
@@ -222,7 +222,7 @@ mkf_utf16le_parser_new(void)
 		return  NULL ;
 	}
 
-	utf16_parser_init( ( mkf_parser_t*) utf16_parser) ;
+	utf16le_parser_init( ( mkf_parser_t*) utf16_parser) ;
 
 	utf16_parser->parser.init = utf16le_parser_init ;
 	utf16_parser->parser.set_str = utf16_parser_set_str ;
