@@ -16,11 +16,10 @@ int  ml_config_proto_final(void) ;
 
 int  ml_gen_proto_challenge(void) ;
 
-int  ml_parse_proto( char **  dev , char **  key , char **  val , char **  str ,
-			int  do_challenge) ;
+char *  ml_parse_proto_prefix( char **  str) ;
 
-int  ml_parse_proto2( char **  file , char **  key , char **  val , char *  str ,
-			int  do_challenge) ;
+int  ml_parse_proto( char **  dev , char **  key , char **  val , char **  str ,
+			int  do_challenge , int  sep_by_semicolon) ;
 
 
 #endif
