@@ -5,6 +5,7 @@
 #include  "ml_cursor.h"
 
 
+#include  <string.h>		/* memset */
 #include  <kiklib/kik_debug.h>
 
 
@@ -19,7 +20,7 @@ cursor_goto(
 	)
 {
 	int  char_index ;
-	int  cols_rest ;
+	u_int  cols_rest ;
 	ml_line_t *  line ;
 
 	if( row > ml_model_end_row( cursor->model))
@@ -35,7 +36,8 @@ cursor_goto(
 
 	if( is_by_col)
 	{
-		char_index = ml_convert_col_to_char_index( line , &cols_rest , col_or_idx , BREAK_BOUNDARY) ;
+		char_index = ml_convert_col_to_char_index( line ,
+					&cols_rest , col_or_idx , BREAK_BOUNDARY) ;
 	}
 	else
 	{
@@ -74,16 +76,8 @@ ml_cursor_init(
 	ml_model_t *  model
 	)
 {
+	memset( cursor , 0 , sizeof(ml_cursor_t)) ;
 	cursor->model = model ;
-
-	cursor->row = 0 ;
-	cursor->char_index = 0 ;
-	cursor->col = 0 ;
-	cursor->col_in_char = 0 ;
-	cursor->saved_row = 0 ;
-	cursor->saved_char_index = 0 ;
-	cursor->saved_col = 0 ;
-	cursor->is_saved = 0 ;
 	
 	return  1 ;
 }
