@@ -104,7 +104,7 @@ int  ml_edit_clear_tab_stop( ml_edit_t *  edit) ;
 
 int  ml_edit_clear_all_tab_stops( ml_edit_t *  edit) ;
 
-ml_line_t *  ml_edit_get_line( ml_edit_t *  edit , int  row) ;
+#define  ml_edit_get_line( edit , row)  (ml_model_get_line( &(edit)->model , row))
 
 int  ml_edit_set_modified_all( ml_edit_t *  edit) ;
 
