@@ -163,6 +163,10 @@ scroll_upward_region(
 	 * This should be done before ml_edit_t data structure is chanegd
 	 * for the listener object to clear existing cache.
 	 */
+#if  0
+	kik_debug_printf( " SCROLL UP region %d %d size %d\n" ,
+		boundary_beg , boundary_end , size) ;
+#endif
 	window_is_scrolled = (*edit->scroll_listener->window_scroll_upward_region)(
 				edit->scroll_listener->self , boundary_beg , boundary_end , size) ;
 	 
@@ -267,6 +271,10 @@ scroll_downward_region(
 	 * This should be done before ml_edit_t data structure is chanegd
 	 * for the listener object to clear existing cache.
 	 */
+#if  0
+	kik_debug_printf( " SCROLL DOWN region %d %d size %d\n" ,
+		boundary_beg , boundary_end , size) ;
+#endif
 	window_is_scrolled = (*edit->scroll_listener->window_scroll_downward_region)(
 				edit->scroll_listener->self , boundary_beg , boundary_end , size) ;
 	
@@ -411,28 +419,22 @@ ml_edsl_insert_new_line(
 	)
 {
 	int  start_row ;
+	int  start_col ;
 	int  end_row ;
 
-	if( edit->cursor.row < edit->scroll_region_beg)
+	if( edit->cursor.row < edit->scroll_region_beg ||
+	    edit->scroll_region_end < edit->cursor.row)
 	{
-		start_row = edit->scroll_region_beg ;
-	}
-	else
-	{
-		start_row = edit->cursor.row ;
-	}
-	
-	if( edit->scroll_region_end < ml_model_end_row( &edit->model))
-	{
-		end_row = edit->scroll_region_end ;
-	}
-	else
-	{
-		end_row = ml_model_end_row( &edit->model) ;
+		return  0 ;
 	}
 
-	copy_lines( edit , start_row + 1 , start_row , end_row - start_row , 1) ;
-	ml_edit_clear_lines( edit , start_row , 1) ;
+	start_row = edit->cursor.row ;
+	start_col = edit->cursor.col ;
+	end_row = edit->scroll_region_end ;
+
+	scroll_downward_region( edit , start_row , end_row , 1) ;
+	ml_cursor_goto_by_col( &edit->cursor , start_col , start_row) ;
+	ml_edit_clear_line_to_right( edit) ;
 
 	return  1 ;
 }
@@ -443,28 +445,28 @@ ml_edsl_delete_line(
 	)
 {
 	int  start_row ;
+	int  start_col ;
 	int  end_row ;
+	int  is_logging ;
 
-	if( edit->cursor.row < edit->scroll_region_beg)
+	if( edit->cursor.row < edit->scroll_region_beg ||
+	    edit->scroll_region_end < edit->cursor.row)
 	{
-		start_row = edit->scroll_region_beg ;
-	}
-	else
-	{
-		start_row = edit->cursor.row ;
+		return  0 ;
 	}
 
-	if( edit->scroll_region_end < ml_model_end_row( &edit->model))
-	{
-		end_row = edit->scroll_region_end ;
-	}
-	else
-	{
-		end_row = ml_model_end_row( &edit->model) ;
-	}
-	
-	copy_lines( edit , start_row , start_row + 1 , end_row - start_row , 1) ;
+	is_logging = edit->is_logging ;
+	edit->is_logging = 0 ;
+
+	start_row = edit->cursor.row ;
+	start_col = edit->cursor.col ;
+	end_row = edit->scroll_region_end ;
+
+	scroll_upward_region( edit , start_row , end_row , 1) ;
 	ml_edit_clear_lines( edit , end_row , 1) ;
-	
+	ml_cursor_goto_by_col( &edit->cursor , start_col , start_row) ;
+
+	edit->is_logging = is_logging ;
+
 	return  1 ;
 }
