@@ -6,7 +6,7 @@
 #define  __ML_PTY_H__
 
 
-#include  <kiklib/kik_config.h>	/* USE_WIN32API */
+#include  <kiklib/kik_def.h>	/* USE_WIN32API */
 #include  <kiklib/kik_types.h>	/* u_int/u_char */
 
 #ifdef  USE_LIBSSH2
@@ -45,8 +45,6 @@ int  ml_set_pty_winsize( ml_pty_ptr_t  pty , u_int  cols , u_int  rows) ;
 
 size_t  ml_write_to_pty( ml_pty_ptr_t  pty , u_char *  buf , size_t  len) ;
 
-size_t  ml_flush_pty( ml_pty_ptr_t  pty) ;
-
 size_t  ml_read_pty( ml_pty_ptr_t  pty , u_char *  buf , size_t  left) ;
 
 pid_t  ml_pty_get_pid( ml_pty_ptr_t  pty) ;
@@ -57,12 +55,6 @@ int  ml_pty_get_slave_fd( ml_pty_ptr_t  pty) ;
 
 char *  ml_pty_get_slave_name( ml_pty_ptr_t  pty) ;
 
-#ifdef  MULTI_WINDOWS_PER_PTY
-int  ml_pty_set_readable( ml_pty_ptr_t  pty , int  is_readable) ;
-
-int  ml_pty_is_readable( ml_pty_ptr_t  pty) ;
-#endif
-
 #ifdef  USE_LIBSSH2
 void *  ml_search_ssh_session( const char *  host , const char *  port , const char *  user) ;
 
@@ -72,6 +64,8 @@ int  ml_pty_unuse_loopback( ml_pty_ptr_t  pty) ;
 
 int  ml_pty_ssh_scp( ml_pty_ptr_t  pty , ml_char_encoding_t  pty_encoding ,
 	ml_char_encoding_t  path_encoding , char *  dst_path , char *  src_path) ;
+
+void  ml_pty_ssh_set_cipher_list( const char *  list) ;
 #endif
 
 
