@@ -5,7 +5,7 @@
 #include  "ml_pty_intern.h"
 
 #include  <libssh2.h>
-#include  <kiklib/kik_config.h>
+#include  <kiklib/kik_def.h>
 #include  <kiklib/kik_debug.h>
 #include  <kiklib/kik_mem.h>
 #include  <kiklib/kik_str.h>
@@ -13,6 +13,7 @@
 #include  <kiklib/kik_path.h>
 #include  <kiklib/kik_unistd.h>		/* kik_usleep */
 #include  <kiklib/kik_locale.h>
+#include  <kiklib/kik_dialog.h>
 
 #ifdef  USE_WIN32API
 #undef  _WIN32_WINNT
@@ -86,6 +87,7 @@ static u_int  num_of_sessions = 0 ;
 #ifdef  USE_WIN32API
 static HANDLE  rd_ev ;
 #endif
+static const char *  cipher_list ;
 
 
 /* --- static functions --- */
@@ -199,10 +201,13 @@ ssh_connect(
 	struct addrinfo  hints ;
 	struct addrinfo *  addr ;
 	struct addrinfo *  addr_p ;
-	const char *  fingerprint ;
+
+	const char *  hostkey ;
+	size_t  hostkey_len ;
+	int  hostkey_type ;
+
 	char *  userauthlist ;
 	int  auth_success = 0 ;
-	int  count ;
 
 	if( ( session = ml_search_ssh_session( host , port , user)))
 	{
@@ -279,11 +284,19 @@ ssh_connect(
 	}
 
 #ifdef  DEBUG
-	libssh2_trace( session->obj , LIBSSH2_TRACE_AUTH) ;
+	libssh2_trace( session->obj , -1) ;
 #endif
 
 	libssh2_session_set_blocking( session->obj , 1) ;
 
+	if( cipher_list)
+	{
+		libssh2_session_method_pref( session->obj ,
+			LIBSSH2_METHOD_CRYPT_CS , cipher_list) ;
+		libssh2_session_method_pref( session->obj ,
+			LIBSSH2_METHOD_CRYPT_SC , cipher_list) ;
+	}
+
 	if( libssh2_session_startup( session->obj , session->sock) != 0)
 	{
 	#ifdef  DEBUG
@@ -293,14 +306,77 @@ ssh_connect(
 		goto  error4 ;
 	}
 
-	fingerprint = libssh2_hostkey_hash( session->obj , LIBSSH2_HOSTKEY_HASH_SHA1) ;
+	/*
+	 * Check ~/.ssh/knownhosts.
+	 */
 
-	kik_msg_printf( "Fingerprint: ") ;
-	for( count = 0 ; count < 20 ; count++)
+	if( ( hostkey = libssh2_session_hostkey( session->obj , &hostkey_len , &hostkey_type)))
 	{
-		kik_msg_printf( "%02X ", (u_char)fingerprint[count]) ;
+		char *  home ;
+		char *  path ;
+		LIBSSH2_KNOWNHOSTS *  nhs ;
+
+		if( ( home = kik_get_home_dir()) &&
+		    ( path = alloca( strlen(home) + 20)) &&
+		    ( nhs = libssh2_knownhost_init( session->obj)) )
+		{
+			struct libssh2_knownhost *  nh ;
+
+		#ifdef  USE_WIN32API
+			sprintf( path , "%s\\mlterm\\known_hosts" , home) ;
+		#else
+			sprintf( path , "%s/.ssh/known_hosts" , home) ;
+		#endif
+
+			libssh2_knownhost_readfile( nhs , path ,
+				LIBSSH2_KNOWNHOST_FILE_OPENSSH) ;
+
+			if( libssh2_knownhost_checkp( nhs , host , atoi( port) ,
+					hostkey , hostkey_len ,
+					LIBSSH2_KNOWNHOST_TYPE_PLAIN|
+					LIBSSH2_KNOWNHOST_KEYENC_RAW ,
+					&nh) != LIBSSH2_KNOWNHOST_CHECK_MATCH)
+			{
+				const char *  hash ;
+				size_t  count ;
+				char *  msg ;
+				char *  p ;
+
+				hash = libssh2_hostkey_hash( session->obj ,
+						LIBSSH2_HOSTKEY_HASH_SHA1) ;
+
+				msg = alloca( strlen( host) + 31 + 3 * 20 + 1) ;
+
+				sprintf( msg , "Connecting to unknown host: %s (" , host) ;
+				p = msg + strlen( msg) ;
+				for( count = 0 ; count < 20 ; count++)
+				{
+					sprintf( p + count * 3 , "%02x:" , (u_char)hash[count]) ;
+				}
+				msg[strlen(msg) - 1] = ')' ;	/* replace ':' with ')' */
+
+				if( ! kik_dialog( KIK_DIALOG_OKCANCEL , msg))
+				{
+					libssh2_knownhost_free( nhs) ;
+
+					goto  error4 ;
+				}
+
+				libssh2_knownhost_add( nhs , host , NULL ,
+						hostkey , hostkey_len ,
+						LIBSSH2_KNOWNHOST_TYPE_PLAIN|
+						LIBSSH2_KNOWNHOST_KEYENC_RAW|
+						LIBSSH2_KNOWNHOST_KEY_SSHRSA , NULL) ;
+
+				libssh2_knownhost_writefile( nhs , path ,
+					LIBSSH2_KNOWNHOST_FILE_OPENSSH) ;
+
+				kik_msg_printf( "Add to %s and continue connecting.\n" , path) ;
+			}
+
+			libssh2_knownhost_free( nhs) ;
+		}
 	}
-	kik_msg_printf("\n") ;
 
 	if( ! ( userauthlist = libssh2_userauth_list( session->obj , user , strlen(user))))
 	{
@@ -366,10 +442,7 @@ ssh_connect(
 		if( libssh2_userauth_publickey_fromfile( session->obj , user ,
 				pubkey , privkey , pass) == 0)
 		{
-		#ifdef  DEBUG
-			kik_debug_printf( KIK_DEBUG_TAG
-				" Authentication by public key succeeded.\n") ;
-		#endif
+			kik_msg_printf( "Authentication by public key succeeded.\n") ;
 
 			auth_success = 1 ;
 		}
@@ -390,10 +463,7 @@ ssh_connect(
 		if( libssh2_userauth_keyboard_interactive(
 			session->obj , user , &kbd_callback) == 0)
 		{
-		#ifdef  DEBUG
-			kik_debug_printf( KIK_DEBUG_TAG
-				" Authentication by keyboard-interactive succeeded.\n") ;
-		#endif
+			kik_msg_printf( "Authentication by keyboard-interactive succeeded.\n") ;
 
 			auth_success = 1 ;
 		}
@@ -411,7 +481,8 @@ ssh_connect(
 		if( ! strstr( userauthlist , "password"))
 		{
 		#ifdef  DEBUG
-			kik_debug_printf( KIK_DEBUG_TAG " No supported authentication methods found.\n") ;
+			kik_debug_printf( KIK_DEBUG_TAG
+				" No supported authentication methods found.\n") ;
 		#endif
 
 			goto  error4 ;
@@ -419,10 +490,8 @@ ssh_connect(
 
 		if( libssh2_userauth_password( session->obj , user , pass) != 0)
 		{
-		#ifdef  DEBUG
-			kik_debug_printf( KIK_DEBUG_TAG
-				" Authentication by password failed.\n") ;
-		#endif
+			kik_msg_printf( "Authentication by password failed.\n") ;
+
 			goto  error4 ;
 		}
 
@@ -943,7 +1012,7 @@ ml_pty_ssh_new(
 		goto  error3 ;
 	}
 
-	if( cmd_argv)
+	if( cmd_path)
 	{
 		int  count ;
 		char *   cmd_line ;
@@ -951,10 +1020,12 @@ ml_pty_ssh_new(
 
 		/* Because cmd_path == cmd_argv[0], cmd_argv[0] is ignored. */
 
+		/* 1 = NULL terminator */
 		cmd_line_len = strlen(cmd_path) + 1 ;
 		for( count = 1 ; cmd_argv[count] != NULL ; count++)
 		{
-			cmd_line_len += (strlen(cmd_argv[count]) + 1) ;
+			/* 3 = " " */
+			cmd_line_len += (strlen(cmd_argv[count]) + 3) ;
 		}
 
 		if( ( cmd_line = alloca( sizeof(char) * cmd_line_len)) == NULL)
@@ -965,8 +1036,9 @@ ml_pty_ssh_new(
 		strcpy( cmd_line, cmd_path) ;
 		for( count = 1 ; cmd_argv[count] != NULL ; count ++)
 		{
-			strcat( cmd_line, " ") ;
-			strcat( cmd_line, cmd_argv[count]) ;
+			sprintf( cmd_line + strlen(cmd_line) ,
+				strchr( cmd_argv[count] , ' ') ? " \"%s\"" : " %s" ,
+				cmd_argv[count]) ;
 		}
 
 		if( libssh2_channel_exec( pty->channel , cmd_line))
@@ -1018,18 +1090,24 @@ ml_pty_ssh_new(
 		u_int  tid ;
 
 		rd_ev = CreateEvent( NULL , FALSE , FALSE , "PTY_READ_READY") ;
-
-		/* Launch the thread that wait for receiving data from pty. */
-		if( ! ( thrd = _beginthreadex( NULL , 0 , wait_pty_read , pty , 0 , &tid)))
+		if( GetLastError() != ERROR_ALREADY_EXISTS)
 		{
-		#ifdef  DEBUG
-			kik_warn_printf( KIK_DEBUG_TAG " CreateThread() failed.\n") ;
-		#endif
+			/* Launch the thread that wait for receiving data from pty. */
+			if( ! ( thrd = _beginthreadex( NULL , 0 , wait_pty_read , pty , 0 , &tid)))
+			{
+			#ifdef  DEBUG
+				kik_warn_printf( KIK_DEBUG_TAG " CreateThread() failed.\n") ;
+			#endif
 
-			goto  error3 ;
+				goto  error3 ;
+			}
+
+			CloseHandle( thrd) ;
+		}
+		else
+		{
+			/* java/MLTerm.java has already watched pty. */
 		}
-
-		CloseHandle( thrd) ;
 	}
 #endif
 
@@ -1449,3 +1527,11 @@ error:
 
 	return  0 ;
 }
+
+void
+ml_pty_ssh_set_cipher_list(
+	const char *  list
+	)
+{
+	cipher_list = list ;
+}
