@@ -24,7 +24,7 @@ ml_term_new(
 	ml_char_encoding_t  encoding ,
 	int  is_auto_encoding ,
 	ml_unicode_policy_t  policy ,
-	int  col_size_a ,
+	u_int  col_size_a ,
 	int  use_char_combining ,
 	int  use_multi_col_char ,
 	int  use_bidi ,
@@ -117,9 +117,6 @@ ml_term_delete(
 		(*term->shape->delete)( term->shape) ;
 	}
 
-#ifdef  MULTI_WINDOWS_PER_PTY
-	free( term->win_id) ;
-#endif
 	free( term->win_name) ;
 	free( term->icon_name) ;
 	free( term->icon_path) ;
@@ -422,19 +419,6 @@ ml_term_write(
 	}
 }
 
-int
-ml_term_flush(
-	ml_term_t *  term
-	)
-{
-	if( term->pty == NULL)
-	{
-		return  0 ;
-	}
-	
-	return  ml_flush_pty( term->pty) ;
-}
-
 int
 ml_term_resize(
 	ml_term_t *  term ,
@@ -889,20 +873,6 @@ ml_term_enter_backscroll_mode(
 	return  ml_enter_backscroll_mode( term->screen) ;
 }
 
-#ifdef  MULTI_WINDOWS_PER_PTY
-int
-ml_term_set_window_id(
-	ml_term_t *  term ,
-	char *  id		/* Could be NULL */
-	)
-{
-	free( term->win_id) ;
-	term->win_id = id ? strdup( id) : NULL ;
-
-	return  1 ;
-}
-#endif
-
 int
 ml_term_set_window_name(
 	ml_term_t *  term ,
