@@ -41,9 +41,6 @@ typedef struct ml_term
 	ml_vertical_mode_t  vertical_mode ;
 	ml_bidi_mode_t  bidi_mode ;
 
-#ifdef  MULTI_WINDOWS_PER_PTY
-	char *  win_id ;
-#endif
 	char *  win_name ;
 	char *  icon_name ;
 	char *  icon_path ;
@@ -61,7 +58,7 @@ typedef struct ml_term
 
 ml_term_t *  ml_term_new( u_int  cols , u_int  rows , u_int  tab_size , u_int  log_size ,
 	ml_char_encoding_t  encoding , int  is_auto_encoding , ml_unicode_policy_t  policy ,
-	int  col_size_a , int  use_char_combining , int  use_multi_col_char , int  use_bidi ,
+	u_int  col_size_a , int  use_char_combining , int  use_multi_col_char , int  use_bidi ,
 	ml_bidi_mode_t  bidi_mode , int  use_ind , int  use_bce , int  use_dynamic_comb ,
 	ml_bs_mode_t  bs_mode , ml_vertical_mode_t  vertical_mode) ;
 
@@ -134,19 +131,10 @@ pid_t  ml_term_get_child_pid( ml_term_t *  term) ;
 
 size_t  ml_term_write( ml_term_t *  term , u_char *  buf , size_t  len , int  to_menu) ;
 
-int  ml_term_flush( ml_term_t *  term) ;
-
 /* Must be called in visual context. */
 #define  ml_term_write_loopback( term , buf , len) \
 		ml_parse_vt100_write_loopback( (term)->parser , buf , len)
 
-#ifdef  MULTI_WINDOWS_PER_PTY
-#define  ml_term_set_readable( term , is_readable) \
-		((term)->pty && ml_pty_set_readable( (term)->pty , is_readable))
-
-#define  ml_term_is_readable( term)  ((term)->pty && ml_pty_is_readable( (term)->pty))
-#endif
-
 int  ml_term_resize( ml_term_t *  term , u_int  cols , u_int  rows) ;
 
 #define  ml_term_cursor_col( term)  ml_screen_cursor_col( (term)->screen)
@@ -279,6 +267,9 @@ int  ml_term_enter_backscroll_mode( ml_term_t *  term) ;
 #define  ml_term_get_mouse_report_mode( term) \
 		ml_vt100_parser_get_mouse_report_mode((term)->parser)
 
+#define  ml_term_get_extended_mouse_report_mode( term) \
+		ml_vt100_parser_get_extended_mouse_report_mode((term)->parser)
+
 #define  ml_term_is_app_keypad( term) \
 		ml_vt100_parser_is_app_keypad((term)->parser)
 
@@ -287,11 +278,7 @@ int  ml_term_enter_backscroll_mode( ml_term_t *  term) ;
 
 #define  ml_term_is_app_escape( term)  ml_vt100_parser_is_app_escape((term)->parser)
 
-#ifdef  MULTI_WINDOWS_PER_PTY
-int  ml_term_set_window_id( ml_term_t *  term , char *  name) ;
-
-#define  ml_term_window_id( term)  ((term)->win_id)
-#endif
+#define  ml_term_want_focus_event( term)  ml_vt100_parser_want_focus_event((term)->parser)
 
 int  ml_term_set_window_name( ml_term_t *  term , char *  name) ;
 
@@ -329,9 +316,5 @@ int  ml_term_start_config_menu( ml_term_t *  term , char *  cmd_path ,
  */
 int  ml_set_auto_restart_cmd( char *  cmd) ;
 
-#ifdef  MULTI_WINDOWS_PER_PTY
-int  ml_term_sync_size( ml_term_t *  term , u_int  cols , u_int  rows) ;
-#endif
-
 
 #endif
