@@ -13,6 +13,7 @@
 #include  <kiklib/kik_util.h>	/* KIK_DIGIT_STR */
 #include  <kiklib/kik_debug.h>
 #include  <kiklib/kik_file.h>	/* kik_file_unset_cloexec */
+#include  <kiklib/kik_unistd.h>	/* kik_setenv/kik_unsetenv */
 
 #include  "ml_config_proto.h"
 
@@ -95,7 +96,7 @@ sig_error(
 		if( fork() > 0)
 		{
 			/* child process */
-			setenv( "INHERIT_PTY_LIST" , env , 1) ;
+			kik_setenv( "INHERIT_PTY_LIST" , env , 1) ;
 
 			if( auto_restart_cmd)
 			{
@@ -146,11 +147,6 @@ sig_child(
 
 			idx = count / MTU ;
 			dead_mask[idx] |= (1 << (count - MTU * idx)) ;
-
-			/* Multiple terms could have the same child. */
-		#ifndef  MULTI_WINDOWS_PER_PTY
-			return ;
-		#endif
 		}
 	}
 }
@@ -343,7 +339,7 @@ ml_create_term(
 			}
 		}
 
-		unsetenv( "INHERIT_PTY_LIST") ;
+		kik_unsetenv( "INHERIT_PTY_LIST") ;
 
 		if( num_of_terms > 0)
 		{
@@ -530,7 +526,10 @@ ml_get_all_terms(
 	ml_term_t ***  _terms
 	)
 {
-	*_terms = terms ;
+	if( _terms)
+	{
+		*_terms = terms ;
+	}
 
 	return  num_of_terms ;
 }
@@ -625,32 +624,3 @@ ml_term_manager_enable_zombie_pty(void)
 {
 	zombie_pty = 1 ;
 }
-
-#ifdef  MULTI_WINDOWS_PER_PTY
-int
-ml_term_sync_size(
-	ml_term_t *  term ,
-	u_int  cols ,
-	u_int  rows
-	)
-{
-	if( ml_term_window_id( term))
-	{
-		u_int  count ;
-		char  seq[6 + DIGIT_STR_LEN(u_int) * 2 + 1] ;
-
-		sprintf( seq , "\x1b[8;%d;%dt" , rows , cols) ;
-
-		for( count = 0 ; count < num_of_terms ; count ++)
-		{
-			if( ml_term_get_master_fd( term) ==
-			    ml_term_get_master_fd( terms[count]))
-			{
-				ml_term_write_loopback( terms[count] , seq , strlen(seq)) ;
-			}
-		}
-	}
-
-	return  1 ;
-}
-#endif
