@@ -15,14 +15,6 @@
 #include  "ml_char_encoding.h"
 
 
-/*
- * kterm BUF_SIZE in ptyx.h is 4096.
- * Following size is adjusted to suppress sizeof(ml_vt100_parser_t) to 4KB.
- * (3984 bytes in ILP32, 4020 bytes in LP64.)
- * Maximum size of sequence parsed once is PTY_RD_BUFFER_SIZE * 3.
- * (see ml_parse_vt100_sequence)
- */
-#define  PTY_RD_BUFFER_SIZE  3072
 #define  PTY_WR_BUFFER_SIZE  100
 
 
@@ -47,23 +39,43 @@ typedef enum  ml_unicode_policy
 typedef enum  ml_mouse_report_mode
 {
 	NO_MOUSE_REPORT = 0 ,
-	MOUSE_REPORT = 1 ,
-	BUTTON_EVENT_MOUSE_REPORT = 2 ,
-	ANY_EVENT_MOUSE_REPORT = 3 ,
+
+	MOUSE_REPORT = 0x1 ,
+	BUTTON_EVENT_MOUSE_REPORT = 0x2 ,
+	ANY_EVENT_MOUSE_REPORT = 0x3 ,
 
 } ml_mouse_report_mode_t ;
 
-typedef struct  ml_char_buffer
+typedef enum  ml_extended_mouse_report_mode
+{
+	NO_EXTENDED_MOUSE_REPORT = 0 ,
+
+	EXTENDED_MOUSE_REPORT_UTF8 = 0x1 ,
+	EXTENDED_MOUSE_REPORT_SGR = 0x2 ,
+	EXTENDED_MOUSE_REPORT_URXVT = 0x3 ,
+
+} ml_extended_mouse_report_mode_t ;
+
+typedef struct  ml_write_buffer
 {
 	ml_char_t  chars[PTY_WR_BUFFER_SIZE] ;
-	u_int  len ;
+	u_int  filled_len ;
 
 	/* for "CSI b"(REP) sequence */
 	ml_char_t *  last_ch ;
 
 	int (*output_func)( ml_screen_t * , ml_char_t *  chars , u_int) ;
 
-}  ml_char_buffer_t ;
+} ml_write_buffer_t ;
+
+typedef struct  ml_read_buffer
+{
+	u_char *  chars ;
+	size_t  len ;
+	size_t  filled_len ;
+	size_t  left ;
+
+} ml_read_buffer_t ;
 
 typedef struct  ml_xterm_event_listener
 {
@@ -122,11 +134,8 @@ typedef struct  ml_vt100_storable_states
 
 typedef struct  ml_vt100_parser
 {
-	u_char  seq[PTY_RD_BUFFER_SIZE] ;
-	size_t  len ;
-	size_t  left ;
-
-	ml_char_buffer_t  buffer ;
+	ml_read_buffer_t  r_buf ;
+	ml_write_buffer_t  w_buf ;
 	
 	ml_pty_ptr_t  pty ;
 	
@@ -141,31 +150,28 @@ typedef struct  ml_vt100_parser
 	
 	mkf_charset_t  cs ;
 
-	ml_unicode_policy_t  unicode_policy ;
-
 	ml_xterm_event_listener_t *  xterm_listener ;
 	ml_config_event_listener_t *  config_listener ;
 
 	int  log_file ;
 
-	ml_mouse_report_mode_t  mouse_mode ;
+	/* ml_unicode_policy_t */ int8_t  unicode_policy ;
+
+	/* ml_mouse_report_mode_t */ int8_t  mouse_mode ;
+	/* ml_extended_mouse_report_mode_t */ int8_t  ext_mouse_mode ;
 
 	/* Used for non iso2022 encoding */
 	int8_t  is_dec_special_in_gl ;
 	int8_t  is_so ;
 	int8_t  is_dec_special_in_g0 ;
 	int8_t  is_dec_special_in_g1 ;
-	
+
 	int8_t  is_bold ;
 	int8_t  is_underlined ;
 	int8_t  is_reversed ;
 
 	u_int8_t  col_size_of_width_a ;	/* 1 or 2 */
 
-	/*
-	 * XXX
-	 * ml_term can access these 3 flags directly.
-	 */
 	int8_t  use_char_combining ;
 	int8_t  use_multi_col_char ;
 	int8_t  logging_vt_seq ;
@@ -175,8 +181,14 @@ typedef struct  ml_vt100_parser
 	int8_t  is_app_escape ;
 	int8_t  is_bracketed_paste_mode ;
 
+	int8_t  want_focus_event ;
+
 	int8_t  im_is_active ;
 
+#ifdef  USE_VT52
+	int8_t  is_vt52_mode ;
+#endif
+
 	/* for save/restore cursor */
 	ml_vt100_storable_states_t  saved_normal ;
 	ml_vt100_storable_states_t  saved_alternate ;
@@ -240,6 +252,9 @@ int  ml_vt100_parser_set_logging_vt_seq( ml_vt100_parser_t *  vt100_parser , int
 
 #define  ml_vt100_parser_get_mouse_report_mode( vt100_parser)  ((vt100_parser)->mouse_mode)
 
+#define  ml_vt100_parser_get_extended_mouse_report_mode( vt100_parser) \
+		((vt100_parser)->ext_mouse_mode)
+
 #define  ml_vt100_parser_is_app_keypad( vt100_parser)  ((vt100_parser)->is_app_keypad)
 
 #define  ml_vt100_parser_is_app_cursor_keys( vt100_parser)  ((vt100_parser)->is_app_cursor_keys)
@@ -249,4 +264,7 @@ int  ml_vt100_parser_set_logging_vt_seq( ml_vt100_parser_t *  vt100_parser , int
 #define  ml_vt100_parser_is_bracketed_paste_mode( vt100_parser) \
 		((vt100_parser)->is_bracketed_paste_mode)
 
+#define  ml_vt100_parser_want_focus_event( vt100_parser)  ((vt100_parser)->want_focus_event)
+
+
 #endif
