@@ -34,7 +34,7 @@ fade_ratio_selected(
 	gpointer  data
 	)
 {
-	free( new_fade_ratio);
+	g_free( new_fade_ratio);
 	new_fade_ratio = gtk_editable_get_chars(GTK_EDITABLE(widget), 0, -1);
 	
 #ifdef  __DEBUG
