@@ -1,5 +1,5 @@
 /*
- *	$Id: mc_sb_view.c,v 1.15 2004/12/06 04:24:41 h_minami Exp $
+ *	$Id$
  */
 
 #include  "mc_sb_view.h"
@@ -16,10 +16,10 @@
 #include  "mc_combo.h"
 #include  "mc_io.h"
 
-#ifndef  DATADIR
+#ifndef  XDATADIR
 #define  SB_DIR  "/usr/local/share/mlterm/scrollbars"
 #else
-#define  SB_DIR  DATADIR "/mlterm/scrollbars"
+#define  SB_DIR  XDATADIR "/mlterm/scrollbars"
 #endif
 
 #define MAX_SCROLLBARS 100
