@@ -546,6 +546,8 @@ ft_font_open(
 	#ifdef  USE_TYPE_XFT
 		return  xft_font_open( font , family , size , encoding , weight , slant ,
 				ch_width , aa_opt) ;
+	#else
+		return  NULL ;
 	#endif
 	}
 	else
@@ -553,10 +555,10 @@ ft_font_open(
 	#ifdef  USE_TYPE_CAIRO
 		return  cairo_font_open( font , family , size , encoding , weight , slant ,
 				ch_width , aa_opt) ;
+	#else
+		return  NULL ;
 	#endif
 	}
-
-	return  NULL ;
 }
 
 u_int  xft_calculate_char_width( x_font_t *  font , const u_char *  ch , size_t  len) ;
@@ -752,7 +754,7 @@ font_found:
 		font->xft_font = xfont ;
 
 		font->height = font->xft_font->height ;
-		font->height_to_baseline = font->xft_font->ascent ;
+		font->ascent = font->xft_font->ascent ;
 
 		if( ch_width == 0)
 		{
@@ -788,7 +790,7 @@ font_found:
 
 		cairo_scaled_font_extents( font->cairo_font , &extents) ;
 		font->height = DOUBLE_ROUNDUP_TO_INT(extents.height) ;
-		font->height_to_baseline = DOUBLE_ROUNDUP_TO_INT(extents.ascent) ;
+		font->ascent = DOUBLE_ROUNDUP_TO_INT(extents.ascent) ;
 
 		/* XXX letter_space is always ignored. */
 		if( font->cols == 2)
@@ -828,7 +830,7 @@ font_found:
 	}
 
 	/*
-	 * checking if font height/height_to_baseline member is sane.
+	 * checking if font height/ascent member is sane.
 	 * font width must be always sane.
 	 */
 
@@ -838,10 +840,10 @@ font_found:
 		font->height = fontsize ;
 	}
 
-	if( font->height_to_baseline == 0)
+	if( font->ascent == 0)
 	{
 		/* XXX this may be inaccurate. */
-		font->height_to_baseline = fontsize ;
+		font->ascent = fontsize ;
 	}
 
 	return  1 ;
@@ -907,21 +909,18 @@ xft_calculate_char_width(
 #if  0
 	else if( len == 2)
 	{
-		FcChar16  xch ;
+		FcChar16  c ;
 
-		xch = ((ch[0] << 8) & 0xff00) | (ch[1] & 0xff) ;
-
-		XftTextExtents16( font->display , font->xft_font , &xch , 1 , &extents) ;
+		c = mkf_bytes_to_int( ch , len) ;
+		XftTextExtents16( font->display , font->xft_font , &c , 1 , &extents) ;
 	}
 #endif
 	else if( len == 4)
 	{
-		FcChar32  xch ;
+		FcChar32  c ;
 
-		xch = ((ch[0] << 24) & 0xff000000) | ((ch[1] << 16) & 0xff0000) |
-			((ch[2] << 8) & 0xff00) | (ch[3] & 0xff) ;
-
-		XftTextExtents32( font->display , font->xft_font , &xch , 1 , &extents) ;
+		c = mkf_bytes_to_int( ch , 4) ;
+		XftTextExtents32( font->display , font->xft_font , &c , 1 , &extents) ;
 	}
 	else
 	{
@@ -986,7 +985,7 @@ cairo_unset_font(
 }
 
 size_t
-x_convert_ucs_to_utf8(
+x_convert_ucs4_to_utf8(
 	u_char *  utf8 ,	/* size of utf8 should be greater than 5. */
 	u_int32_t  ucs
 	)
@@ -1060,7 +1059,7 @@ cairo_calculate_char_width(
 	cairo_text_extents_t  extents ;
 	int  width ;
 
-	utf8[ x_convert_ucs_to_utf8( utf8 , mkf_bytes_to_int( ch , len))] = '\0' ;
+	utf8[ x_convert_ucs4_to_utf8( utf8 , mkf_bytes_to_int( ch , len))] = '\0' ;
 	cairo_scaled_font_text_extents( font->cairo_font , utf8 , &extents) ;
 
 #if  0
