@@ -5,5 +5,8 @@
 #ifndef  USE_TYPE_XFT
 #define  USE_TYPE_XFT
 #endif
+#ifdef  USE_TYPE_CAIRO
+#undef  USE_TYPE_CAIRO
+#endif
 
 #include  "x_font_ft.c"
