@@ -26,7 +26,7 @@ typedef struct  x_color_manager
 		char *  name ;
 		u_int8_t  is_loaded ;
 	
-	} sys_colors[4] ;
+	} sys_colors[6] ;
 
 	u_int8_t  alpha ;
 	int8_t  is_reversed ;
@@ -36,7 +36,8 @@ typedef struct  x_color_manager
 
 x_color_manager_t *  x_color_manager_new( x_display_t *  disp ,
 	x_color_config_t *  color_config , char *  fg_color , char *  bg_color ,
-	char *  cursor_fg_color , char *  cursor_bg_color) ;
+	char *  cursor_fg_color , char *  cursor_bg_color ,
+	char *  bd_color , char *  ul_color) ;
 
 int  x_color_manager_delete( x_color_manager_t *  color_man) ;
 
@@ -48,6 +49,10 @@ int  x_color_manager_set_cursor_fg_color( x_color_manager_t *  color_man , char
 
 int  x_color_manager_set_cursor_bg_color( x_color_manager_t *  color_man , char *  name) ;
 
+int  x_color_manager_set_bd_color( x_color_manager_t *  color_man , char *  name) ;
+
+int  x_color_manager_set_ul_color( x_color_manager_t *  color_man , char *  name) ;
+
 char *  x_color_manager_get_fg_color( x_color_manager_t *  color_man) ;
 
 char *  x_color_manager_get_bg_color( x_color_manager_t *  color_man) ;
@@ -56,6 +61,10 @@ char *  x_color_manager_get_cursor_fg_color( x_color_manager_t *  color_man) ;
 
 char *  x_color_manager_get_cursor_bg_color( x_color_manager_t *  color_man) ;
 
+char *  x_color_manager_get_bd_color( x_color_manager_t *  color_man) ;
+
+char *  x_color_manager_get_ul_color( x_color_manager_t *  color_man) ;
+
 x_color_t *  x_get_xcolor( x_color_manager_t *  color_man , ml_color_t  color) ;
 
 int  x_color_manager_fade( x_color_manager_t *  color_man , u_int  fade_ratio) ;
@@ -70,6 +79,10 @@ int  x_color_manager_adjust_cursor_fg_color( x_color_manager_t *  color_man) ;
 
 int  x_color_manager_adjust_cursor_bg_color( x_color_manager_t *  color_man) ;
 
+int  x_color_manager_adjust_bd_color( x_color_manager_t *  color_man) ;
+
+int  x_color_manager_adjust_ul_color( x_color_manager_t *  color_man) ;
+
 int  x_color_manager_unload( x_color_manager_t *  color_man) ;
 
 int  x_color_manager_change_alpha( x_color_manager_t *  color_man , u_int8_t  alpha) ;
