@@ -11,9 +11,37 @@
 
 /* --- static functions --- */
 
-/*
- * drawing string
- */
+static int
+adjust_bd_ul_color(
+	x_color_manager_t *  color_man ,
+	ml_color_t  fg_color ,
+	ml_color_t  bg_color ,
+	ml_font_t  font ,
+	int  is_underlined
+	)
+{
+	if( font & FONT_BOLD)
+	{
+		/* If bg_color == ML_FG_COLOR, it seems to be reversed. */
+		if( ( fg_color == ML_FG_COLOR || bg_color == ML_FG_COLOR) &&
+		    x_color_manager_adjust_bd_color( color_man))
+		{
+			return  1 ;
+		}
+	}
+
+	if( is_underlined)
+	{
+		if( ( fg_color == ML_FG_COLOR || bg_color == ML_FG_COLOR) &&
+		    x_color_manager_adjust_ul_color( color_man))
+		{
+			return  2 ;
+		}
+	}
+
+	return  0 ;
+}
+
 
 #if  ! defined(NO_DYNAMIC_LOAD_TYPE) || defined(USE_TYPE_XFT) || defined(USE_TYPE_CAIRO)
 
@@ -28,13 +56,18 @@ fc_draw_combining_chars(
 	int  y
 	)
 {
-	int  count ;
+	u_int  count ;
 	u_char *  ch_bytes ;
 	size_t  ch_size ;
 	mkf_charset_t  ch_cs ;
 
 	for( count = 0 ; count < size ; count ++)
 	{
+		if( ml_char_cols( &chars[count]) == 0)
+		{
+			continue ;
+		}
+
 		ch_bytes = ml_char_bytes( &chars[count]) ;
 		ch_size = ml_char_size( &chars[count]) ;
 		ch_cs = ml_char_cs( &chars[count]) ;
@@ -55,24 +88,19 @@ fc_draw_combining_chars(
 		}
 		else
 		{
-			/* FcChar32 */ u_int32_t  xch ;
-
-			char  ucs4_bytes[4] ;
+			u_char  ucs4_bytes[4] ;
+			/* FcChar32 */ u_int32_t  ucs4 ;
 
 			if( ! x_convert_to_xft_ucs4( ucs4_bytes , ch_bytes , ch_size , ch_cs))
 			{
 				return  0 ;
 			}
 
-			xch = ((ucs4_bytes[0] << 24) & 0xff000000) |
-				((ucs4_bytes[1] << 16) & 0xff0000) |
-				((ucs4_bytes[2] << 8) & 0xff00) |
-				(ucs4_bytes[3] & 0xff) ;
-
+			ucs4 = mkf_bytes_to_int( ucs4_bytes , 4) ;
 			x_window_ft_draw_string32( window ,
 				x_get_font( font_man , ml_char_font( &chars[count])) ,
 				x_get_xcolor( color_man , ml_char_fg_color( &chars[count])) ,
-				x , y , &xch , 1) ;
+				x , y , &ucs4 , 1) ;
 		}
 	}
 
@@ -90,9 +118,10 @@ fc_draw_str(
 	int  x ,
 	int  y ,
 	u_int  height ,
-	u_int  height_to_baseline ,
+	u_int  ascent ,
 	u_int  top_margin ,
-	u_int  bottom_margin
+	u_int  bottom_margin ,
+	int  hide_underline
 	)
 {
 	int  count ;
@@ -139,6 +168,13 @@ fc_draw_str(
 	end_of_str = 0 ;
 
 	count = 0 ;
+	while( ml_char_cols( &chars[count]) == 0)
+	{
+		if( ++ count >= num_of_chars)
+		{
+			return  1 ;
+		}
+	}
 
 	ch_bytes = ml_char_bytes( &chars[count]) ;
 	ch_size = ml_char_size( &chars[count]) ;
@@ -202,7 +238,7 @@ fc_draw_str(
 		}
 		else /* if( state == 2) */
 		{
-			char  ucs4_bytes[4] ;
+			u_char  ucs4_bytes[4] ;
 
 			if( ! x_convert_to_xft_ucs4( ucs4_bytes , ch_bytes , ch_size , ch_cs))
 			{
@@ -216,10 +252,7 @@ fc_draw_str(
 				ucs4_bytes[3] = 0x20 ;
 			}
 
-			str32[str_len++] = ((ucs4_bytes[0] << 24) & 0xff000000) |
-						((ucs4_bytes[1] << 16) & 0xff0000) |
-						((ucs4_bytes[2] << 8) & 0xff00) |
-						(ucs4_bytes[3] & 0xff) ;
+			str32[str_len++] = mkf_bytes_to_int( ucs4_bytes , 4) ;
 		}
 
 		comb_chars = ml_get_combining_chars( &chars[count] , &comb_size) ;
@@ -228,14 +261,19 @@ fc_draw_str(
 		 * next character.
 		 */
 
-		count ++ ;
-
-		if( count >= num_of_chars)
+		do
 		{
-			start_draw = 1 ;
-			end_of_str = 1 ;
+			if( ++ count >= num_of_chars)
+			{
+				start_draw = 1 ;
+				end_of_str = 1 ;
+
+				break ;
+			}
 		}
-		else
+		while( ml_char_cols( &chars[count]) == 0) ;
+
+		if( ! end_of_str)
 		{
 			ch_bytes = ml_char_bytes( &chars[count]) ;
 			ch_size = ml_char_size( &chars[count]) ;
@@ -297,10 +335,15 @@ fc_draw_str(
 			 * status is changed.
 			 */
 
+			int  color_adjusted ;	/* 0 => None , 1 => BD , 2 => UL */
+
 		#ifdef  PERF_DEBUG
 			draw_count ++ ;
 		#endif
 
+			color_adjusted = adjust_bd_ul_color( color_man , fg_color , bg_color ,
+							xfont->id , is_underlined) ;
+
 			/*
 			 * clearing background
 			 */
@@ -323,19 +366,19 @@ fc_draw_str(
 			{
 				x_window_ft_draw_string8( window ,
 					xfont , x_get_xcolor( color_man , fg_color) ,
-					x , y + height_to_baseline , str8 , str_len) ;
+					x , y + ascent , str8 , str_len) ;
 			}
 			else if( state == 1)
 			{
 				x_window_draw_decsp_string( window , xfont ,
 					x_get_xcolor( color_man , fg_color) ,
-					x , y + height_to_baseline , str8 , str_len) ;
+					x , y + ascent , str8 , str_len) ;
 			}
 			else /* if( state == 2) */
 			{
 				x_window_ft_draw_string32( window ,
 					xfont , x_get_xcolor( color_man , fg_color) ,
-					x , y + height_to_baseline , str32 , str_len) ;
+					x , y + ascent , str32 , str_len) ;
 			}
 
 			if( comb_chars)
@@ -353,26 +396,38 @@ fc_draw_str(
 				#if  0
 					current_width
 				#else
-					x
+					current_width - ch_width
 				#endif
-					, y + height_to_baseline) ;
+					, y + ascent) ;
 			}
 
-			if( is_underlined)
+			if( ! hide_underline && color_adjusted != 2 && is_underlined)
 			{
 				if( xfont->is_vertical)
 				{
 					x_window_fill_with( window ,
 						x_get_xcolor( color_man , fg_color) ,
-						x , y , (ch_width>>4) + 1 , height) ;
+						x , y , (ch_width >> 4) + 1 , height) ;
 				}
 				else
 				{
 					x_window_fill_with( window ,
 						x_get_xcolor( color_man , fg_color) ,
-						x , y + height_to_baseline ,
+						x , y + ascent ,
 						current_width - x ,
-						((height_to_baseline - bottom_margin)>>4) +1 ) ;
+						((ascent - bottom_margin) >> 4) + 1 ) ;
+				}
+			}
+
+			if( color_adjusted)
+			{
+				if( color_adjusted == 1)
+				{
+					x_color_manager_adjust_bd_color( color_man) ;
+				}
+				else /* if( color_adjusted == 2) */
+				{
+					x_color_manager_adjust_ul_color( color_man) ;
 				}
 			}
 
@@ -411,86 +466,6 @@ fc_draw_str(
 
 #if  ! defined(NO_DYNAMIC_LOAD_TYPE) || defined(USE_TYPE_XCORE)
 
-static u_int		/* Return written size of XChar2b */
-convert_ucs4_to_utf16(
-	XChar2b *  dst ,	/* 2 XChar2b's */
-	u_char *  src		/* 4 bytes. Big endian. */
-	)
-{
-	/*
-	 * WIN32: Little endian utf16.
-	 * Xlib: Big endian utf16.
-	 */
-
-#if  0
-	kik_debug_printf( KIK_DEBUG_TAG "%.8x => " , mkf_bytes_to_int( src , 4)) ;
-#endif
-
-	if( src[0] > 0x0 || src[1] > 0x10)
-	{
-		return  0 ;
-	}
-	else if( src[1] == 0x0)
-	{
-	#ifdef  USE_WIN32GUI
-		dst[0].byte2 = src[2] ;
-		dst[0].byte1 = src[3] ;
-	#else
-		dst[0].byte1 = src[2] ;
-		dst[0].byte2 = src[3] ;
-	#endif
-	
-		return  1 ;
-	}
-	else /* if( src[1] <= 0x10) */
-	{
-		/* surrogate pair */
-
-		u_int32_t  linear ;
-		u_char  c ;
-
-		linear = mkf_bytes_to_int( src , 4) - 0x10000 ;
-
-		c = (u_char)( linear / (0x100 * 0x400)) ;
-		linear -= (c * 0x100 * 0x400) ;
-	#ifdef  USE_WIN32GUI
-		dst[0].byte2 = c + 0xd8 ;
-	#else
-		dst[0].byte1 = c + 0xd8 ;
-	#endif
-	
-		c = (u_char)( linear / 0x400) ;
-		linear -= (c * 0x400) ;
-	#ifdef  USE_WIN32GUI
-		dst[0].byte1 = c ;
-	#else
-		dst[0].byte2 = c ;
-	#endif
-	
-		c = (u_char)( linear / 0x100) ;
-		linear -= (c * 0x100) ;
-	#ifdef  USE_WIN32GUI
-		dst[1].byte2 = c + 0xdc ;
-		dst[1].byte1 = (u_char) linear ;
-	#else
-		dst[1].byte1 = c + 0xdc ;
-		dst[1].byte2 = (u_char) linear ;
-	#endif
-
-	#if  0
-		kik_msg_printf( "%.2x%.2x%.2x%.2x\n" ,
-		#ifdef  USE_WIN32GUI
-			dst[0].byte2 , dst[0].byte1 , dst[1].byte2 , dst[1].byte1
-		#else
-			dst[0].byte1 , dst[0].byte2 , dst[1].byte1 , dst[1].byte2
-		#endif
-			) ;
-	#endif
-	
-		return  2 ;
-	}
-}
-
 static int
 xcore_draw_combining_chars(
 	x_window_t *  window ,
@@ -502,12 +477,17 @@ xcore_draw_combining_chars(
 	int  y
 	)
 {
-	int  count ;
+	u_int  count ;
 	u_char *  ch_bytes ;
 	size_t  ch_size ;
 
 	for( count = 0 ; count < size ; count ++)
 	{
+		if( ml_char_cols( &chars[count]) == 0)
+		{
+			continue ;
+		}
+
 		ch_bytes = ml_char_bytes( &chars[count]) ;
 		ch_size = ml_char_size( &chars[count]) ;
 
@@ -545,7 +525,7 @@ xcore_draw_combining_chars(
 			XChar2b  xch[2] ;
 			u_int  len ;
 
-			if( ( len = convert_ucs4_to_utf16( xch , ch_bytes)) > 0)
+			if( ( len = (x_convert_ucs4_to_utf16( xch , ch_bytes) / 2)) > 0)
 			{
 				x_window_draw_string16( window ,
 					x_get_font( font_man , ml_char_font( &chars[count])) ,
@@ -575,9 +555,10 @@ xcore_draw_str(
 	int  x ,
 	int  y ,
 	u_int  height ,
-	u_int  height_to_baseline ,
+	u_int  ascent ,
 	u_int  top_margin ,
-	u_int  bottom_margin
+	u_int  bottom_margin ,
+	int  hide_underline
 	)
 {
 	int  count ;
@@ -621,6 +602,13 @@ xcore_draw_str(
 	}
 
 	count = 0 ;
+	while( ml_char_cols( &chars[count]) == 0)
+	{
+		if( ++ count >= num_of_chars)
+		{
+			return  1 ;
+		}
+	}
 
 	start_draw = 0 ;
 	end_of_str = 0 ;
@@ -693,7 +681,7 @@ xcore_draw_str(
 		{
 			/* UCS4 */
 
-			str_len += convert_ucs4_to_utf16( str2b + str_len , ch_bytes) ;
+			str_len += (x_convert_ucs4_to_utf16( str2b + str_len , ch_bytes) / 2) ;
 		}
 		else
 		{
@@ -719,14 +707,19 @@ xcore_draw_str(
 		 * next character.
 		 */
 
-		count ++ ;
-
-		if( count >= num_of_chars)
+		do
 		{
-			start_draw = 1 ;
-			end_of_str = 1 ;
+			if( ++ count >= num_of_chars)
+			{
+				start_draw = 1 ;
+				end_of_str = 1 ;
+
+				break ;
+			}
 		}
-		else
+		while( ml_char_cols( &chars[count]) == 0) ;
+
+		if( ! end_of_str)
 		{
 			ch_bytes = ml_char_bytes( &chars[count]) ;
 			ch_size = ml_char_size( &chars[count]) ;
@@ -788,10 +781,15 @@ xcore_draw_str(
 			 * status is changed.
 			 */
 
+			int  color_adjusted ;	/* 0 => None , 1 => BD , 2 => UL */
+
 		#ifdef  PERF_DEBUG
 			draw_count ++ ;
 		#endif
 
+			color_adjusted = adjust_bd_ul_color( color_man , fg_color , bg_color ,
+							xfont->id , is_underlined) ;
+
 			if( ( x_window_has_wall_picture( window) && bg_color == ML_BG_COLOR) ||
 				bottom_margin + top_margin > 0 /* == line space XXX */|| 
 				( xfont->is_proportional && ! xfont->is_var_col_width))
@@ -816,19 +814,19 @@ xcore_draw_str(
 				{
 					x_window_draw_string16( window , xfont ,
 						x_get_xcolor( color_man , fg_color) ,
-						x , y + height_to_baseline , str2b , str_len) ;
+						x , y + ascent , str2b , str_len) ;
 				}
 				else if( state == 1)
 				{
 					x_window_draw_decsp_string( window , xfont ,
 						x_get_xcolor( color_man , fg_color) ,
-						x , y + height_to_baseline , str , str_len) ;
+						x , y + ascent , str , str_len) ;
 				}
 				else /* if( state == 0) */
 				{
 					x_window_draw_string( window , xfont ,
 						x_get_xcolor( color_man , fg_color) ,
-						x , y + height_to_baseline , str , str_len) ;
+						x , y + ascent , str , str_len) ;
 				}
 			}
 			else
@@ -838,21 +836,21 @@ xcore_draw_str(
 					x_window_draw_image_string16( window , xfont ,
 						x_get_xcolor( color_man , fg_color) ,
 						x_get_xcolor( color_man , bg_color) ,
-						x , y + height_to_baseline , str2b , str_len) ;
+						x , y + ascent , str2b , str_len) ;
 				}
 				else if( state == 1)
 				{
 					x_window_draw_decsp_image_string( window , xfont ,
 						x_get_xcolor( color_man , fg_color) ,
 						x_get_xcolor( color_man , bg_color) ,
-						x , y + height_to_baseline , str , str_len) ;
+						x , y + ascent , str , str_len) ;
 				}
 				else /* if( state == 0) */
 				{
 					x_window_draw_image_string( window , xfont ,
 						x_get_xcolor( color_man , fg_color) ,
 						x_get_xcolor( color_man , bg_color) ,
-						x , y + height_to_baseline , str , str_len) ;
+						x , y + ascent , str , str_len) ;
 				}
 			}
 
@@ -871,26 +869,38 @@ xcore_draw_str(
 				#if  0
 					current_width
 				#else
-					x
+					current_width - ch_width
 				#endif
-					, y + height_to_baseline) ;
+					, y + ascent) ;
 			}
 
-			if( is_underlined)
+			if( ! hide_underline && color_adjusted != 2 && is_underlined)
 			{
 				if( xfont->is_vertical)
 				{
 					x_window_fill_with( window ,
 						x_get_xcolor( color_man , fg_color) ,
-						x , y , (ch_width>>4) + 1 , height) ;
+						x , y , (ch_width >> 4) + 1 , height) ;
 				}
 				else
 				{
 					x_window_fill_with( window ,
 						x_get_xcolor( color_man , fg_color) ,
-						x , y + height_to_baseline ,
+						x , y + ascent ,
 						current_width - x ,
-						((height_to_baseline - bottom_margin)>>4) +1 ) ;
+						((ascent - bottom_margin) >> 4) + 1) ;
+				}
+			}
+
+			if( color_adjusted)
+			{
+				if( color_adjusted == 1)
+				{
+					x_color_manager_adjust_bd_color( color_man) ;
+				}
+				else /* if( color_adjusted == 2) */
+				{
+					x_color_manager_adjust_ul_color( color_man) ;
 				}
 			}
 
@@ -939,9 +949,10 @@ x_draw_str(
 	int  x ,
 	int  y ,
 	u_int  height ,
-	u_int  height_to_baseline ,
+	u_int  ascent ,
 	u_int  top_margin ,
-	u_int  bottom_margin
+	u_int  bottom_margin ,
+	int  hide_underline
 	)
 {
 	u_int  updated_width ;
@@ -954,8 +965,9 @@ x_draw_str(
 #if  ! defined(NO_DYNAMIC_LOAD_TYPE) || defined(USE_TYPE_XFT) || defined(USE_TYPE_CAIRO)
 	case  TYPE_XFT:
 	case  TYPE_CAIRO:
-		if( ! fc_draw_str( window , font_man , color_man , &updated_width , chars , num_of_chars ,
-			x , y , height , height_to_baseline , top_margin , bottom_margin))
+		if( ! fc_draw_str( window , font_man , color_man , &updated_width ,
+			chars , num_of_chars , x , y , height , ascent ,
+			top_margin , bottom_margin , hide_underline))
 		{
 			return  0 ;
 		}
@@ -965,8 +977,9 @@ x_draw_str(
 
 #if  ! defined(NO_DYNAMIC_LOAD_TYPE) || defined(USE_TYPE_XCORE)
 	case  TYPE_XCORE:
-		if( ! xcore_draw_str( window , font_man , color_man , &updated_width , chars , num_of_chars ,
-			x , y , height , height_to_baseline , top_margin , bottom_margin))
+		if( ! xcore_draw_str( window , font_man , color_man , &updated_width ,
+			chars , num_of_chars , x , y , height , ascent ,
+			top_margin , bottom_margin , hide_underline))
 		{
 			return  0 ;
 		}
@@ -988,9 +1001,10 @@ x_draw_str_to_eol(
 	int  x ,
 	int  y ,
 	u_int  height ,
-	u_int  height_to_baseline ,
+	u_int  ascent ,
 	u_int  top_margin ,
-	u_int  bottom_margin
+	u_int  bottom_margin ,
+	int  hide_underline
 	)
 {
 	u_int  updated_width ;
@@ -1003,8 +1017,9 @@ x_draw_str_to_eol(
 #if  ! defined(NO_DYNAMIC_LOAD_TYPE) || defined(USE_TYPE_XFT) || defined(USE_TYPE_CAIRO)
 	case  TYPE_XFT:
 	case  TYPE_CAIRO:
-		if( ! fc_draw_str( window , font_man , color_man , &updated_width , chars , num_of_chars ,
-			x , y , height , height_to_baseline , top_margin , bottom_margin))
+		if( ! fc_draw_str( window , font_man , color_man , &updated_width ,
+			chars , num_of_chars , x , y , height , ascent ,
+			top_margin , bottom_margin , hide_underline))
 		{
 			return  0 ;
 		}
@@ -1014,8 +1029,9 @@ x_draw_str_to_eol(
 
 #if  ! defined(NO_DYNAMIC_LOAD_TYPE) || defined(USE_TYPE_XCORE)
 	case  TYPE_XCORE:
-		if( ! xcore_draw_str( window , font_man , color_man , &updated_width , chars , num_of_chars ,
-			x , y , height , height_to_baseline , top_margin , bottom_margin))
+		if( ! xcore_draw_str( window , font_man , color_man , &updated_width ,
+			chars , num_of_chars , x , y , height , ascent ,
+			top_margin , bottom_margin , hide_underline))
 		{
 			return	0 ;
 		}
