@@ -464,14 +464,6 @@ x_set_use_multi_col_char(
 	return  1 ;
 }
 
-int
-x_is_using_multi_col_char(
-	x_font_manager_t *  font_man
-	)
-{
-	return  font_man->font_cache->use_multi_col_char ;
-}
-
 int
 x_set_letter_space(
 	x_font_manager_t *  font_man ,
@@ -499,14 +491,6 @@ x_set_letter_space(
 	return  1 ;
 }
 
-u_int
-x_get_letter_space(
-	x_font_manager_t *  font_man
-	)
-{
-	return  font_man->font_cache->letter_space ;
-}
-
 XFontSet
 x_get_fontset(
 	x_font_manager_t *  font_man
