@@ -280,9 +280,10 @@ draw_screen_vertical(
 				    j * xfont->width ,
 				    (xfont->height + LINE_SPACE) * (i - top) ,
 				    xfont->height + LINE_SPACE ,
-				    xfont->height_to_baseline + LINE_SPACE / 2 ,
+				    xfont->ascent + LINE_SPACE / 2 ,
 				    LINE_SPACE / 2 ,
-				    LINE_SPACE / 2 + LINE_SPACE % 2) ;
+				    LINE_SPACE / 2 + LINE_SPACE % 2 ,
+				    1 /* no need to draw underline */) ;
 		}
 
 		/*
@@ -299,9 +300,10 @@ draw_screen_vertical(
 				   xfont->width * (num_of_digits + 1) ,
 				   (xfont->height + LINE_SPACE) * (i - top) ,
 				   xfont->height + LINE_SPACE ,
-				   xfont->height_to_baseline + LINE_SPACE / 2 ,
+				   xfont->ascent + LINE_SPACE / 2 ,
 				   LINE_SPACE / 2 ,
-				   LINE_SPACE / 2 + LINE_SPACE % 2) ;
+				   LINE_SPACE / 2 + LINE_SPACE % 2 ,
+				   1 /* no need to draw underline */) ;
 	}
 
 	/*
@@ -363,8 +365,8 @@ draw_screen_vertical(
 				    x + i * xfont->width ,
 				    (xfont->height + LINE_SPACE) * cand_screen->num_per_window + LINE_SPACE,
 				    xfont->height ,
-				    xfont->height_to_baseline ,
-				    0 , 0) ;
+				    xfont->ascent ,
+				    0 , 0 , 1 /* no need to draw underline */) ;
 		}
 	}
 }
@@ -447,9 +449,10 @@ draw_screen_horizontal(
 				    &ch , 1 ,
 				    x , 0 ,
 				    xfont->height + LINE_SPACE ,
-				    xfont->height_to_baseline + LINE_SPACE / 2 ,
+				    xfont->ascent + LINE_SPACE / 2 ,
 				    LINE_SPACE / 2 ,
-				    LINE_SPACE / 2 + LINE_SPACE % 2) ;
+				    LINE_SPACE / 2 + LINE_SPACE % 2 ,
+				    1 /* no need to draw underline */) ;
 			x += xfont->width ;
 		}
 
@@ -466,9 +469,10 @@ draw_screen_horizontal(
 			    cand_screen->candidates[i].filled_len ,
 			    x , 0 ,
 			    xfont->height + LINE_SPACE ,
-			    xfont->height_to_baseline + LINE_SPACE / 2 ,
+			    xfont->ascent + LINE_SPACE / 2 ,
 			    LINE_SPACE / 2 ,
-			    LINE_SPACE / 2 + LINE_SPACE % 2) ;
+			    LINE_SPACE / 2 + LINE_SPACE % 2 ,
+			    1 /* no need to draw underline */) ;
 		x += candidate_width( cand_screen->font_man ,
 				      &cand_screen->candidates[i]) ;
 
@@ -545,11 +549,8 @@ adjust_window_position(
 		return ;
 	}
 
-	dh = DisplayHeight(  cand_screen->window.disp->display ,
-			     cand_screen->window.disp->screen) ;
-	dw = DisplayWidth(  cand_screen->window.disp->display ,
-			     cand_screen->window.disp->screen) ;
-
+	dh = cand_screen->window.disp->height ;
+	dw = cand_screen->window.disp->width ;
 
 	if( *y + cand_screen->window.height > dh)
 	{
@@ -1029,7 +1030,7 @@ x_im_candidate_screen_new(
 	cand_screen->listener.self = NULL ;
 	cand_screen->listener.selected = NULL ;
 
-	if( ! x_display_show_root( disp , &cand_screen->window , x , y , 0 ,
+	if( ! x_display_show_root( disp , &cand_screen->window , x , y , XValue | YValue ,
 					  "mlterm-candidate-window" , 0))
 	{
 	#ifdef  DEBUG
