@@ -7,6 +7,7 @@
 #include  <kiklib/kik_conf_io.h>
 #include  <kiklib/kik_mem.h>	/* malloc/realloc */
 #include  <kiklib/kik_str.h>	/* kik_str_to_uint */
+#include  <kiklib/kik_locale.h>	/* kik_get_lang */
 
 
 /* --- global functions --- */
@@ -139,6 +140,8 @@ x_prepare_for_main_config(
 		"process received (pasted) strings via Unicode [false]") ;
 	kik_conf_add_opt( conf , 'V' , "varwidth" , 1 , "use_variable_column_width" ,
 		"variable column width (for proportional/ISCII) [false]") ;
+	kik_conf_add_opt( conf , 'W' , "sep" , 0 , "word_separators" ,
+		"word-separating characters for double-click [,.:;/@]") ;
 	kik_conf_add_opt( conf , 'X' , "alpha" , 0 , "alpha" ,
 		"alpha blending for translucent [255]") ;
 	kik_conf_add_opt( conf , 'Z' , "multicol" , 1 , "use_multi_column_char" ,
@@ -192,9 +195,15 @@ x_prepare_for_main_config(
 		"bidi mode [normal]") ;
 #endif
 	kik_conf_add_opt( conf , '\0' , "im" , 0 , "input_method" ,
-		"input method (xim/kbd/uim/iiimf/m17nlib/scim/none) [xim]") ;
+		"input method (xim/kbd/uim/m17nlib/scim/none) [xim]") ;
 	kik_conf_add_opt( conf , '\0' , "parent" , 0 , "parent_window" ,
 		"parent window") ;
+	kik_conf_add_opt( conf , '\0' , "bd" , 0 , "bd_color" ,
+		"Color to use to display bold characters (equivalent to colorBD)") ;
+	kik_conf_add_opt( conf , '\0' , "ul" , 0 , "ul_color" ,
+		"Color to use to display underlined characters (equivalent to colorUL)") ;
+	kik_conf_add_opt( conf , '\0' , "noul" , 1 , "hide_underline" ,
+		"Don't draw underline [false]") ;
 #if  defined(USE_WIN32API) || defined(USE_LIBSSH2)
 	kik_conf_add_opt( conf , '\0' , "servlist" , 0 , "server_list" ,
 		"list of servers to connect") ;
@@ -222,15 +231,37 @@ x_prepare_for_main_config(
 		"[~/.ssh/id_rsa]"
 	#endif
 		) ;
+	kik_conf_add_opt( conf , '\0' , "ciphlist" , 0 , "cipher_list" ,
+		"preferred cipher list") ;
 #endif
 	kik_conf_add_opt( conf , '\0' , "csp" , 0 , "letter_space" ,
 		"extra space between letters in pixels [0]") ;
 	kik_conf_add_opt( conf , '\0' , "ucsprop" , 1 , "use_unicode_property" ,
 		"use unicode property for characters [false]") ;
-	kik_conf_add_opt( conf , '\0' , "logmsg" , 1 , "logging_msg" ,
-		"output messages to ~/.mlterm/msg.log [true]") ;
 	kik_conf_add_opt( conf , '\0' , "osc52" , 1 , "allow_osc52" ,
 		"allow access to clipboard by OSC 52 sequence [false]") ;
+	kik_conf_add_opt( conf , '\0' , "blink" , 1 , "blink_cursor" ,
+		"blink cursor [false]") ;
+	kik_conf_add_opt( conf , '\0' , "border" , 0 , "inner_border" ,
+		"inner border [2]") ;
+	kik_conf_add_opt( conf , '\0' , "button3" , 0 , "button3_behavior" ,
+		"button3 behavior. (xterm/menu1/menu2/menu3) "
+	#ifdef  USE_WIN32GUI
+		"[xterm]"
+	#else
+		"[menu1]"
+	#endif
+		) ;
+	kik_conf_add_opt( conf , '\0' , "clip" , 1 , "use_clipboard" ,
+		"use CLIPBOARD (not only PRIMARY) selection [false]") ;
+	kik_conf_add_opt( conf , '\0' , "restart" , 1 , "auto_restart" ,
+		"restart mlterm automatically if an error like segv happens. [true]") ;
+	kik_conf_add_opt( conf , '\0' , "logmsg" , 1 , "logging_msg" ,
+		"output messages to ~/.mlterm/msg.log [true]") ;
+#ifdef  USE_IM_CURSOR_COLOR
+	kik_conf_add_opt( conf , '\0' , "imcolor" , 0 , "im_cursor_color" ,
+		"cursor color when input method is activated. [false]") ;
+#endif
 	kik_conf_set_end_opt( conf , 'e' , NULL , "exec_cmd" , 
 		"execute external command") ;
 
@@ -248,16 +279,6 @@ x_main_config_init(
 	char *  value ;
 	char *  invalid_msg = "%s %s is not valid.\n" ;
 
-	if( ( value = kik_conf_get_value( conf , "logging_msg")) &&
-	    strcmp( value , "false") == 0)
-	{
-		kik_set_msg_log_file_name( NULL) ;
-	}
-	else
-	{
-		kik_set_msg_log_file_name( "mlterm/msg.log") ;
-	}
-
 #ifndef  USE_WIN32GUI
 	if( ( value = kik_conf_get_value( conf , "display")) == NULL)
 #endif
@@ -379,6 +400,16 @@ x_main_config_init(
 		}
 	}
 
+	if( ( value = kik_conf_get_value( conf , "logging_msg")) &&
+	    strcmp( value , "false") == 0)
+	{
+		kik_set_msg_log_file_name( NULL) ;
+	}
+	else
+	{
+		kik_set_msg_log_file_name( "mlterm/msg.log") ;
+	}
+
 	main_config->step_in_changing_font_size = 1 ;
 	
 	if( ( value = kik_conf_get_value( conf , "step_in_changing_font_size")))
@@ -478,7 +509,21 @@ x_main_config_init(
 	{
 		main_config->cursor_bg_color = strdup( value) ;
 	}
-	
+
+	main_config->bd_color = NULL ;
+
+	if( ( value = kik_conf_get_value( conf , "bd_color")))
+	{
+		main_config->bd_color = strdup( value) ;
+	}
+
+	main_config->ul_color = NULL ;
+
+	if( ( value = kik_conf_get_value( conf , "ul_color")))
+	{
+		main_config->ul_color = strdup( value) ;
+	}
+
 	main_config->sb_fg_color = NULL ;
 	
 	if( ( value = kik_conf_get_value( conf , "sb_fg_color")))
@@ -506,30 +551,36 @@ x_main_config_init(
 	main_config->y = 0 ;
 	main_config->cols = 80 ;
 	main_config->rows = 24 ;
+	main_config->geom_hint = 0 ;
 	
 	if( ( value = kik_conf_get_value( conf , "geometry")))
 	{
 	#ifdef  USE_WIN32GUI
-		/*
-		 * "+[x]+[y]" is igonred.
-		 */
-		char *  p ;
+		int  x ;
+		int  y ;
 		u_int  cols ;
 		u_int  rows ;
 
-		main_config->geom_hint = 0 ;
-		p = value ;
-
-		if( ( p = strchr( value, '+')))
-		{
-			*p = '\0' ;
-		}
-
-		if( sscanf( value, "%ux%u", &cols, &rows) == 2)
+		if( sscanf( value , "%ux%u+%d+%d" , &cols , &rows , &x , &y) == 4)
 		{
+			main_config->geom_hint = XValue|YValue|WidthValue|HeightValue ;
+			main_config->x = x ;
+			main_config->y = y ;
 			main_config->cols = cols ;
 			main_config->rows = rows ;
 		}
+		else if( sscanf( value , "%ux%u", &cols, &rows) == 2)
+		{
+			main_config->geom_hint = WidthValue|HeightValue ;
+			main_config->cols = cols ;
+			main_config->rows = rows ;
+		}
+		else if( sscanf( value , "+%d+%d" , &x , &y) == 2)
+		{
+			main_config->geom_hint = XValue|YValue ;
+			main_config->x = x ;
+			main_config->y = y ;
+		}
 	#else
 		/*
 		 * For each value not found, the argument is left unchanged.
@@ -538,6 +589,7 @@ x_main_config_init(
 		main_config->geom_hint = XParseGeometry( value ,
 						&main_config->x , &main_config->y ,
 						&main_config->cols , &main_config->rows) ;
+	#endif
 
 		if( main_config->cols == 0 || main_config->rows == 0)
 		{
@@ -546,11 +598,6 @@ x_main_config_init(
 			main_config->cols = 80 ;
 			main_config->rows = 24 ;
 		}
-	#endif
-	}
-	else
-	{
-		main_config->geom_hint = 0 ;
 	}
 
 	main_config->screen_width_ratio = 100 ;
@@ -757,9 +804,16 @@ x_main_config_init(
 			main_config->receive_string_via_ucs = 1 ;
 		}
 	}
-	
-	/* default value is used */
-	main_config->col_size_of_width_a = 1 ;
+
+	/* "cn" and "ko" ? */
+	if( strcmp( kik_get_lang() , "ja") == 0)
+	{
+		main_config->col_size_of_width_a = 2 ;
+	}
+	else
+	{
+		main_config->col_size_of_width_a = 1 ;
+	}
 	
 	if( ( value = kik_conf_get_value( conf , "col_size_of_width_a")))
 	{
@@ -887,13 +941,18 @@ x_main_config_init(
 	main_config->is_auto_encoding = 0 ;
 	if( ( value = kik_conf_get_value( conf , "ENCODING")))
 	{
-		if( ( main_config->encoding = ml_get_char_encoding( value)) == ML_UNKNOWN_ENCODING)
+		while( ( main_config->encoding = ml_get_char_encoding( value))
+			== ML_UNKNOWN_ENCODING)
 		{
 			kik_msg_printf(
 				"%s encoding is not supported. Auto detected encoding is used.\n" ,
 				value) ;
-				
-			main_config->encoding = ml_get_char_encoding( "auto") ;
+
+			value = "auto" ;
+		}
+
+		if( strcmp( value , "auto") == 0)
+		{
 			main_config->is_auto_encoding = 1 ;
 		}
 	}
@@ -1174,6 +1233,11 @@ x_main_config_init(
 	{
 		main_config->private_key = strdup( value) ;
 	}
+
+	if( ( value = kik_conf_get_value( conf , "cipher_list")))
+	{
+		ml_pty_ssh_set_cipher_list( strdup( value)) ;
+	}
 #endif
 
 	main_config->allow_osc52 = 0 ;
@@ -1186,6 +1250,72 @@ x_main_config_init(
 		}
 	}
 
+	main_config->blink_cursor = 0 ;
+
+	if( ( value = kik_conf_get_value( conf , "blink_cursor")))
+	{
+		if( strcmp( value , "true") == 0)
+		{
+			main_config->blink_cursor = 1 ;
+		}
+	}
+
+	main_config->margin = 2 ;
+
+	if( ( value = kik_conf_get_value( conf , "inner_border")))
+	{
+		u_int  margin ;
+
+		if( kik_str_to_uint( &margin , value) && margin <= 255)
+		{
+			main_config->margin = margin ;
+		}
+	}
+
+	main_config->hide_underline = 0 ;
+
+	if( ( value = kik_conf_get_value( conf , "hide_underline")))
+	{
+		if( strcmp( value , "true") == 0)
+		{
+			main_config->hide_underline = 1 ;
+		}
+	}
+
+	if( ( value = kik_conf_get_value( conf , "word_separators")))
+	{
+		ml_set_word_separators( value) ;
+	}
+
+	if( ( value = kik_conf_get_value( conf , "button3_behavior")))
+	{
+		x_set_button3_behavior( value) ;
+	}
+
+	if( ( value = kik_conf_get_value( conf , "use_clipboard")))
+	{
+		if( strcmp( value , "true") == 0)
+		{
+			x_set_use_clipboard_selection( 1) ;
+		}
+	}
+
+	if( ! ( value = kik_conf_get_value( conf , "auto_restart")) ||
+	    strcmp( value , "false") != 0)
+	{
+		ml_set_auto_restart_cmd( kik_get_prog_path()) ;
+	}
+
+#ifdef  USE_IM_CURSOR_COLOR
+	if( ( value = kik_conf_get_value( conf , "im_cursor_color")))
+	{
+		if( *value)
+		{
+			x_set_im_cursor_color( value) ;
+		}
+	}
+#endif
+
 	if( ( value = kik_conf_get_value( conf , "exec_cmd")) && strcmp( value , "true") == 0)
 	{
 		if( ( main_config->cmd_argv = malloc( sizeof( char*) * (argc + 1))) == NULL)
@@ -1246,8 +1376,6 @@ x_main_config_final(
 	free( main_config->input_method) ;
 	free( main_config->init_str) ;
 
-	kik_set_msg_log_file_name(NULL) ;
-
 #if  defined(USE_WIN32API) || defined(USE_LIBSSH2)
 	if( main_config->server_list)
 	{
