@@ -19,7 +19,7 @@ static char *   mod_meta_mode_name_table[] =
 /* --- global functions --- */
 
 x_mod_meta_mode_t
-x_get_mod_meta_mode(
+x_get_mod_meta_mode_by_name(
 	char *  name
 	)
 {
