@@ -28,12 +28,12 @@ typedef struct x_system_event_listener
 {
 	void *  self ;
 
-	void  (*open_screen)( void * , x_screen_ptr_t , char *) ;
-	void  (*close_screen)( void * , x_screen_ptr_t , char *) ;
+	void  (*open_screen)( void * , x_screen_ptr_t) ;
+	void  (*close_screen)( void * , x_screen_ptr_t) ;
 	void  (*open_pty)( void * , x_screen_ptr_t , char *) ;
 	void  (*next_pty)( void * , x_screen_ptr_t) ;
 	void  (*prev_pty)( void * , x_screen_ptr_t) ;
-	void  (*close_pty)( void * , x_screen_ptr_t) ;
+	void  (*close_pty)( void * , x_screen_ptr_t , char *) ;
 	
 	void  (*pty_closed)( void * , x_screen_ptr_t) ;
 
@@ -130,10 +130,14 @@ typedef struct  x_screen
 
 	char *  pic_file_path ;
 	x_picture_modifier_t  pic_mod ;
-	x_bg_picture_t *  bg_pic ;
+	x_picture_t *  bg_pic ;
 
 	x_icon_picture_t *  icon ;
 
+#ifdef  ENABLE_SIXEL
+	x_picture_manager_t *  pic_man ;
+#endif
+
 	/*
 	 * These members mustn't be changed by mlterm configuration protocol,
 	 * since they can be executed.
@@ -142,7 +146,7 @@ typedef struct  x_screen
 	char *  conf_menu_path_2 ;
 	char *  conf_menu_path_3 ;
 
-	char  prev_mouse_report_seq[3] ;
+	char  prev_mouse_report_seq[5] ;
 
 	u_int8_t  fade_ratio ;
 	u_int8_t  line_space ;
@@ -151,6 +155,8 @@ typedef struct  x_screen
 	int8_t  use_extended_scroll_shortcut ;
 	int8_t  borderless ;
 	int8_t  font_or_color_config_updated ;	/* 0x1 = font updated, 0x2 = color updated */
+	int8_t  cursor_blink_wait ;
+	int8_t  hide_underline ;
 
 } x_screen_t ;
 
@@ -170,7 +176,8 @@ x_screen_t *  x_screen_new( ml_term_t *  term , x_font_manager_t *  font_man ,
 	int  use_transbg , int  use_vertical_cursor , int  big5_buggy ,
 	char *  conf_menu_path_1 , char *  conf_menu_path_2 , char *  conf_menu_path_3 ,
 	int  use_extended_scroll_shortcut , int  borderless , u_int  line_space ,
-	char *  input_method , int  allow_osc52) ;
+	char *  input_method , int  allow_osc52 , int  blink_cursor , int  margin ,
+	int  hide_underline) ;
 
 int  x_screen_delete( x_screen_t *  screen) ;
 
@@ -198,7 +205,7 @@ u_int  x_col_width( x_screen_t *  screen) ;
 
 u_int  x_line_height( x_screen_t *  screen) ;
 
-u_int  x_line_height_to_baseline( x_screen_t *  screen) ;
+u_int  x_line_ascent( x_screen_t *  screen) ;
 
 u_int  x_line_top_margin( x_screen_t *  screen) ;
 
