@@ -35,14 +35,16 @@
 #define  PARENT_WINDOWID_IS_TOP(win)  ((win)->parent_window == (win)->disp->my_window)
 
 
-typedef enum  x_event_dispatch
+typedef enum  x_resize_flag
 {
 	NOTIFY_TO_NONE = 0x0 ,
 	NOTIFY_TO_CHILDREN = 0x01 ,
 	NOTIFY_TO_PARENT = 0x02 ,
-	NOTIFY_TO_MYSELF = 0x04
+	NOTIFY_TO_MYSELF = 0x04 ,
 
-} x_event_dispatch_t ;
+	LIMIT_RESIZE = 0x08 ,
+
+} x_resize_flag_t ;
 
 typedef struct  x_xim_event_listener
 {
@@ -148,6 +150,7 @@ typedef struct  x_window
 
 #ifdef  USE_WIN32GUI
 	Pixmap  wall_picture ;
+	int  cmd_show ;
 #else
 	int8_t  wall_picture_is_set ;	/* Actually set picture (including transparency) or not. */
 #endif
@@ -164,6 +167,8 @@ typedef struct  x_window
 
 	void (*window_realized)( struct x_window *) ;
 	void (*window_finalized)( struct x_window *) ;
+	void (*window_deleted)( struct x_window *) ;
+	void (*mapping_notify)( struct x_window *) ;
 	/* Win32: gc->gc is not None. */
 	void (*window_exposed)( struct x_window * , int , int , u_int , u_int) ;
 	/* Win32: gc->gc is not None. */
@@ -188,8 +193,7 @@ typedef struct  x_window
 	 * for x_im_xxx_screen_t.
 	 */
 	void (*set_xdnd_config)( struct x_window * , char * ,  char * , char * ) ;
-	void (*window_deleted)( struct x_window *) ;
-	void (*mapping_notify)( struct x_window *) ;
+	void (*idling)( struct x_window *) ;
 
 } x_window_t ;
 
@@ -197,7 +201,7 @@ typedef struct  x_window
 int  x_window_init( x_window_t *  win ,
 	u_int  width , u_int  height , u_int  min_width , u_int  min_height ,
 	u_int  base_width , u_int  base_height , u_int  width_inc ,
-	u_int  height_inc , u_int  margin, int  create_gc) ;
+	u_int  height_inc , u_int  margin , int  create_gc) ;
 
 int  x_window_final( x_window_t *  win) ;
 
@@ -247,10 +251,10 @@ int  x_window_map( x_window_t *  win) ;
 
 int  x_window_unmap( x_window_t *  win) ;
 
-int  x_window_resize( x_window_t *  win , u_int  width , u_int  height , x_event_dispatch_t  flag) ;
+int  x_window_resize( x_window_t *  win , u_int  width , u_int  height , x_resize_flag_t  flag) ;
 
 int  x_window_resize_with_margin( x_window_t *  win , u_int  width , u_int  height ,
-	x_event_dispatch_t  flag) ;
+	x_resize_flag_t  flag) ;
 
 int  x_window_set_normal_hints( x_window_t *  win , u_int  min_width , u_int  min_height ,
 	u_int  base_width , u_int  base_height , u_int  width_inc , u_int  height_inc) ;
@@ -289,7 +293,7 @@ int  x_window_receive_event( x_window_t *  win , XEvent *  event) ;
 size_t  x_window_get_str( x_window_t *  win , u_char *  seq , size_t  seq_len ,
 	mkf_parser_t **  parser , KeySym *  keysym , XKeyEvent *  event) ;
 
-int  x_window_is_scrollable( x_window_t *  win) ;
+#define  x_window_is_scrollable(win)  ((win)->is_scrollable)
 
 int  x_window_scroll_upward( x_window_t *  win , u_int  height) ;
 
@@ -311,6 +315,9 @@ int  x_window_scroll_rightward_region( x_window_t *  win ,
 
 int  x_window_scroll_rightward( x_window_t *  win , u_int  width) ;
 
+int  x_window_copy_area( x_window_t *  win , Pixmap  src , int  src_x , int  src_y ,
+	u_int  width , u_int  height , int  dst_x , int  dst_y) ;
+
 int  x_window_draw_decsp_string( x_window_t *  win , x_font_t *  font ,
 	x_color_t *  fg_color , int  x , int  y , u_char *  str , u_int  len) ;
 
@@ -387,17 +394,11 @@ u_int  x_window_get_mod_ignore_mask( x_window_t *  win , KeySym *  keysyms) ;
 
 u_int  x_window_get_mod_meta_mask( x_window_t *  win , char *  mod_key) ;
 
-int  x_window_bell( x_window_t *  win) ;
+int  x_window_bell( x_window_t *  win , int  visual) ;
 
 int  x_window_translate_coordinates( x_window_t *  win, int x, int y,
 	int *  global_x, int *  global_y, Window *  child) ;
 
-#if  0
-/* Not used */
-int  x_window_paste( x_window_t *  win , Drawable  src , int  src_x , int  src_y ,
-	u_int  src_width , u_int  src_height , int  dst_x , int  dst_y) ;
-#endif
-
 #ifdef  DEBUG
 void  x_window_dump_children( x_window_t *  win) ;
 #endif
